-- This software is copyright Kong Inc. and its licensors.
-- Use of the software is subject to the agreement between your organization
-- and Kong Inc. If there is no such agreement, use is governed by and
-- subject to the terms of the Kong Master Software License Agreement found
-- at https://konghq.com/enterprisesoftwarelicense/.
-- [ END OF LICENSE 0867164ffc95e54f04670b5169c09574bdbd9bba ]

local _Type = {}

_Type.WRAPPER = {
    NONE = nil,
    LIST = 1,
    NON_NULL = 2
}


-- @param _type: another Type object, or string if wrapper is NONE (nil)
-- @param wrapper: see _Type.WRAPPER
function _Type.new(_type, wrapper) -- luacheck: ignore
    local self = {}
    self.type = _type
    self.wrapper = wrapper
    _Type.__index = _Type
    return setmetatable(self, _Type)
end


function _Type:is_wrapped()
    return self.wrapper ~= _Type.WRAPPER.NONE
end


function _Type:name()
    if self:is_wrapped() then return error("Wrapped type has no name") end
    return self.type
end


-- Unwrap one level
function _Type:unwrap()
    if not self:is_wrapped() then return error("Cannot unwrap base type") end
    return self.type
end


-- Returns unwrapped Type object of base level
function _Type:unwrap_f()
    if self:is_wrapped() then
        return self.type:unwrap_f()
    end
    return self
end


return _Type
