-- This software is copyright Kong Inc. and its licensors.
-- Use of the software is subject to the agreement between your organization
-- and Kong Inc. If there is no such agreement, use is governed by and
-- subject to the terms of the Kong Master Software License Agreement found
-- at https://konghq.com/enterprisesoftwarelicense/.
-- [ END OF LICENSE 0867164ffc95e54f04670b5169c09574bdbd9bba ]

local typedefs = require "kong.db.schema.typedefs"


local is_present = function(v)
  return type(v) == "string" and #v > 0
end


return {
  name = "request-termination",
  fields = {
    { protocols = typedefs.protocols_http },
    { config = {
        type = "record",
        fields = {
          { status_code = {
            type = "integer",
            default = 503,
            between = { 100, 599 },
          }, },
          { message = { type = "string" }, },
          { content_type = { type = "string" }, },
          { body = { type = "string" }, },
          { echo = { type = "boolean", required = true, default = false }, },
          { trigger = typedefs.header_name }
        },
        custom_validator = function(config)
          if is_present(config.message)
          and(is_present(config.content_type)
              or is_present(config.body)) then
            return nil, "message cannot be used with content_type or body"
          end
          if is_present(config.content_type)
          and not is_present(config.body) then
            return nil, "content_type requires a body"
          end
          if config.echo and (
            is_present(config.content_type) or
            is_present(config.body)) then
            return nil, "echo cannot be used with content_type and body"
          end
          return true
        end,
      },
    },
  },
}
