local decode = require("cjson").new().decode
return assert(decode([===[
{
  "version": "2.0",
  "metadata": {
    "apiVersion": "2018-03-22",
    "endpointPrefix": "personalize-events",
    "jsonVersion": "1.1",
    "protocol": "rest-json",
    "serviceFullName": "Amazon Personalize Events",
    "serviceId": "Personalize Events",
    "signatureVersion": "v4",
    "signingName": "personalize",
    "uid": "personalize-events-2018-03-22"
  },
  "operations": {
    "PutEvents": {
      "name": "PutEvents",
      "http": {
        "method": "POST",
        "requestUri": "/events"
      },
      "input": {
        "shape": "PutEventsRequest"
      },
      "errors": [
        {
          "shape": "InvalidInputException"
        }
      ],
      "documentation": "<p>Records user interaction event data. For more information see <a>event-record-api</a>.</p>"
    }
  },
  "shapes": {
    "Date": {
      "type": "timestamp"
    },
    "Event": {
      "type": "structure",
      "required": [
        "eventType",
        "sentAt"
      ],
      "members": {
        "eventId": {
          "shape": "StringType",
          "documentation": "<p>An ID associated with the event. If an event ID is not provided, Amazon Personalize generates a unique ID for the event. An event ID is not used as an input to the model. Amazon Personalize uses the event ID to distinquish unique events. Any subsequent events after the first with the same event ID are not used in model training.</p>"
        },
        "eventType": {
          "shape": "StringType",
          "documentation": "<p>The type of event. This property corresponds to the <code>EVENT_TYPE</code> field of the Interactions schema.</p>"
        },
        "eventValue": {
          "shape": "FloatType",
          "documentation": "<p>The event value that corresponds to the <code>EVENT_VALUE</code> field of the Interactions schema.</p>"
        },
        "itemId": {
          "shape": "ItemId",
          "documentation": "<p>The item ID key that corresponds to the <code>ITEM_ID</code> field of the Interactions schema.</p>"
        },
        "properties": {
          "shape": "EventPropertiesJSON",
          "documentation": "<p>A string map of event-specific data that you might choose to record. For example, if a user rates a movie on your site, other than movie ID (<code>itemId</code>) and rating (<code>eventValue</code>) , you might also send the number of movie ratings made by the user.</p> <p>Each item in the map consists of a key-value pair. For example,</p> <p> <code>{\"numberOfRatings\": \"12\"}</code> </p> <p>The keys use camel case names that match the fields in the Interactions schema. In the above example, the <code>numberOfRatings</code> would match the 'NUMBER_OF_RATINGS' field defined in the Interactions schema.</p>",
          "jsonvalue": true
        },
        "sentAt": {
          "shape": "Date",
          "documentation": "<p>The timestamp (in Unix time) on the client side when the event occurred.</p>"
        },
        "recommendationId": {
          "shape": "RecommendationId",
          "documentation": "<p>The ID of the recommendation.</p>"
        },
        "impression": {
          "shape": "Impression",
          "documentation": "<p>A list of item IDs that represents the sequence of items you have shown the user. For example, <code>[\"itemId1\", \"itemId2\", \"itemId3\"]</code>.</p>"
        }
      },
      "documentation": "<p>Represents user interaction event information sent using the <code>PutEvents</code> API.</p>"
    },
    "EventList": {
      "type": "list",
      "member": {
        "shape": "Event"
      },
      "max": 10,
      "min": 1
    },
    "EventPropertiesJSON": {
      "type": "string",
      "max": 1024,
      "min": 1
    },
    "FloatType": {
      "type": "float"
    },
    "Impression": {
      "type": "list",
      "member": {
        "shape": "ItemId"
      },
      "max": 25,
      "min": 1
    },
    "ItemId": {
      "type": "string",
      "max": 256,
      "min": 1
    },
    "PutEventsRequest": {
      "type": "structure",
      "required": [
        "trackingId",
        "sessionId",
        "eventList"
      ],
      "members": {
        "trackingId": {
          "shape": "StringType",
          "documentation": "<p>The tracking ID for the event. The ID is generated by a call to the <a href=\"https://docs.aws.amazon.com/personalize/latest/dg/API_CreateEventTracker.html\">CreateEventTracker</a> API.</p>"
        },
        "userId": {
          "shape": "UserId",
          "documentation": "<p>The user associated with the event.</p>"
        },
        "sessionId": {
          "shape": "StringType",
          "documentation": "<p>The session ID associated with the user's visit. Your application generates the sessionId when a user first visits your website or uses your application. Amazon Personalize uses the sessionId to associate events with the user before they log in. For more information see <a>event-record-api</a>.</p>"
        },
        "eventList": {
          "shape": "EventList",
          "documentation": "<p>A list of event data from the session.</p>"
        }
      }
    },
    "RecommendationId": {
      "type": "string",
      "max": 40,
      "min": 1
    },
    "StringType": {
      "type": "string",
      "max": 256,
      "min": 1
    },
    "UserId": {
      "type": "string",
      "max": 256,
      "min": 1
    }
  },
  "documentation": "<p>Amazon Personalize can consume real-time user event data, such as <i>stream</i> or <i>click</i> data, and use it for model training either alone or combined with historical data. For more information see <a>recording-events</a>.</p>"
}
]===]))
