local decode = require("cjson").new().decode
return assert(decode([===[
{ "schemas": { "Row": { "description": "Report data for each row. For example if RunReportRequest contains: ```none \"dimensions\": [ { \"name\": \"eventName\" }, { \"name\": \"countryId\" } ], \"metrics\": [ { \"name\": \"eventCount\" } ] ``` One row with 'in_app_purchase' as the eventName, 'JP' as the countryId, and 15 as the eventCount, would be: ```none \"dimensionValues\": [ { \"value\": \"in_app_purchase\" }, { \"value\": \"JP\" } ], \"metricValues\": [ { \"value\": \"15\" } ] ```", "type": "object", "id": "Row", "properties": { "dimensionValues": { "items": { "$ref": "DimensionValue" }, "type": "array", "description": "List of requested dimension values. In a PivotReport, dimension_values are only listed for dimensions included in a pivot." }, "metricValues": { "type": "array", "description": "List of requested visible metric values.", "items": { "$ref": "MetricValue" } } } }, "InListFilter": { "properties": { "values": { "type": "array", "description": "The list of string values. Must be non-empty.", "items": { "type": "string" } }, "caseSensitive": { "type": "boolean", "description": "If true, the string value is case sensitive." } }, "type": "object", "description": "The result needs to be in a list of string values.", "id": "InListFilter" }, "ResponseMetaData": { "description": "Response's metadata carrying additional information about the report content.", "properties": { "subjectToThresholding": { "description": "If `subjectToThresholding` is true, this report is subject to thresholding and only returns data that meets the minimum aggregation thresholds. It is possible for a request to be subject to thresholding thresholding and no data is absent from the report, and this happens when all data is above the thresholds. To learn more, see [Data thresholds](https://support.google.com/analytics/answer/9383630) and [About Demographics and Interests](https://support.google.com/analytics/answer/2799357).", "type": "boolean" }, "timeZone": { "description": "The property's current timezone. Intended to be used to interpret time-based dimensions like `hour` and `minute`. Formatted as strings from the IANA Time Zone database (https://www.iana.org/time-zones); for example \"America/New_York\" or \"Asia/Tokyo\".", "type": "string" }, "dataLossFromOtherRow": { "type": "boolean", "description": "If true, indicates some buckets of dimension combinations are rolled into \"(other)\" row. This can happen for high cardinality reports." }, "schemaRestrictionResponse": { "$ref": "SchemaRestrictionResponse", "description": "Describes the schema restrictions actively enforced in creating this report. To learn more, see [Access and data-restriction management](https://support.google.com/analytics/answer/10851388)." }, "currencyCode": { "type": "string", "description": "The currency code used in this report. Intended to be used in formatting currency metrics like `purchaseRevenue` for visualization. If currency_code was specified in the request, this response parameter will echo the request parameter; otherwise, this response parameter is the property's current currency_code. Currency codes are string encodings of currency types from the ISO 4217 standard (https://en.wikipedia.org/wiki/ISO_4217); for example \"USD\", \"EUR\", \"JPY\". To learn more, see https://support.google.com/analytics/answer/9796179." }, "emptyReason": { "type": "string", "description": "If empty reason is specified, the report is empty for this reason." } }, "id": "ResponseMetaData", "type": "object" }, "Filter": { "description": "An expression to filter dimension or metric values.", "type": "object", "properties": { "numericFilter": { "$ref": "NumericFilter", "description": "A filter for numeric or date values." }, "inListFilter": { "$ref": "InListFilter", "description": "A filter for in list values." }, "betweenFilter": { "$ref": "BetweenFilter", "description": "A filter for two values." }, "fieldName": { "type": "string", "description": "The dimension name or metric name. In most methods, dimensions & metrics can be used for the first time in this field. However in a RunPivotReportRequest, this field must be additionally specified by name in the RunPivotReportRequest's dimensions or metrics." }, "stringFilter": { "description": "Strings related filter.", "$ref": "StringFilter" } }, "id": "Filter" }, "NumericValue": { "id": "NumericValue", "properties": { "int64Value": { "format": "int64", "description": "Integer value", "type": "string" }, "doubleValue": { "format": "double", "description": "Double value", "type": "number" } }, "description": "To represent a number.", "type": "object" }, "Cohort": { "description": "Defines a cohort selection criteria. A cohort is a group of users who share a common characteristic. For example, users with the same `firstSessionDate` belong to the same cohort.", "properties": { "dimension": { "description": "Dimension used by the cohort. Required and only supports `firstSessionDate`.", "type": "string" }, "name": { "type": "string", "description": "Assigns a name to this cohort. The dimension `cohort` is valued to this name in a report response. If set, cannot begin with `cohort_` or `RESERVED_`. If not set, cohorts are named by their zero based index `cohort_0`, `cohort_1`, etc." }, "dateRange": { "description": "The cohort selects users whose first touch date is between start date and end date defined in the `dateRange`. This `dateRange` does not specify the full date range of event data that is present in a cohort report. In a cohort report, this `dateRange` is extended by the granularity and offset present in the `cohortsRange`; event data for the extended reporting date range is present in a cohort report. In a cohort request, this `dateRange` is required and the `dateRanges` in the `RunReportRequest` or `RunPivotReportRequest` must be unspecified. This `dateRange` should generally be aligned with the cohort's granularity. If `CohortsRange` uses daily granularity, this `dateRange` can be a single day. If `CohortsRange` uses weekly granularity, this `dateRange` can be aligned to a week boundary, starting at Sunday and ending Saturday. If `CohortsRange` uses monthly granularity, this `dateRange` can be aligned to a month, starting at the first and ending on the last day of the month.", "$ref": "DateRange" } }, "id": "Cohort", "type": "object" }, "CohortSpec": { "properties": { "cohortReportSettings": { "$ref": "CohortReportSettings", "description": "Optional settings for a cohort report." }, "cohorts": { "description": "Defines the selection criteria to group users into cohorts. Most cohort reports define only a single cohort. If multiple cohorts are specified, each cohort can be recognized in the report by their name.", "items": { "$ref": "Cohort" }, "type": "array" }, "cohortsRange": { "$ref": "CohortsRange", "description": "Cohort reports follow cohorts over an extended reporting date range. This range specifies an offset duration to follow the cohorts over." } }, "type": "object", "description": "The specification of cohorts for a cohort report. Cohort reports create a time series of user retention for the cohort. For example, you could select the cohort of users that were acquired in the first week of September and follow that cohort for the next six weeks. Selecting the users acquired in the first week of September cohort is specified in the `cohort` object. Following that cohort for the next six weeks is specified in the `cohortsRange` object. For examples, see [Cohort Report Examples](https://developers.google.com/analytics/devguides/reporting/data/v1/advanced#cohort_report_examples). The report response could show a weekly time series where say your app has retained 60% of this cohort after three weeks and 25% of this cohort after six weeks. These two percentages can be calculated by the metric `cohortActiveUsers/cohortTotalUsers` and will be separate rows in the report.", "id": "CohortSpec" }, "RunPivotReportRequest": { "id": "RunPivotReportRequest", "description": "The request to generate a pivot report.", "type": "object", "properties": { "returnPropertyQuota": { "type": "boolean", "description": "Toggles whether to return the current state of this Analytics Property's quota. Quota is returned in [PropertyQuota](#PropertyQuota)." }, "dimensionFilter": { "$ref": "FilterExpression", "description": "The filter clause of dimensions. Dimensions must be requested to be used in this filter. Metrics cannot be used in this filter." }, "metrics": { "description": "The metrics requested, at least one metric needs to be specified. All defined metrics must be used by one of the following: metric_expression, metric_filter, order_bys.", "items": { "$ref": "Metric" }, "type": "array" }, "cohortSpec": { "description": "Cohort group associated with this request. If there is a cohort group in the request the 'cohort' dimension must be present.", "$ref": "CohortSpec" }, "dimensions": { "items": { "$ref": "Dimension" }, "description": "The dimensions requested. All defined dimensions must be used by one of the following: dimension_expression, dimension_filter, pivots, order_bys.", "type": "array" }, "pivots": { "items": { "$ref": "Pivot" }, "description": "Describes the visual format of the report's dimensions in columns or rows. The union of the fieldNames (dimension names) in all pivots must be a subset of dimension names defined in Dimensions. No two pivots can share a dimension. A dimension is only visible if it appears in a pivot.", "type": "array" }, "keepEmptyRows": { "description": "If false or unspecified, each row with all metrics equal to 0 will not be returned. If true, these rows will be returned if they are not separately removed by a filter.", "type": "boolean" }, "dateRanges": { "items": { "$ref": "DateRange" }, "type": "array", "description": "The date range to retrieve event data for the report. If multiple date ranges are specified, event data from each date range is used in the report. A special dimension with field name \"dateRange\" can be included in a Pivot's field names; if included, the report compares between date ranges. In a cohort request, this `dateRanges` must be unspecified." }, "currencyCode": { "description": "A currency code in ISO4217 format, such as \"AED\", \"USD\", \"JPY\". If the field is empty, the report uses the property's default currency.", "type": "string" }, "property": { "description": "A Google Analytics GA4 property identifier whose events are tracked. Specified in the URL path and not the body. To learn more, see [where to find your Property ID](https://developers.google.com/analytics/devguides/reporting/data/v1/property-id). Within a batch request, this property should either be unspecified or consistent with the batch-level property. Example: properties/1234", "type": "string" }, "metricFilter": { "$ref": "FilterExpression", "description": "The filter clause of metrics. Applied at post aggregation phase, similar to SQL having-clause. Metrics must be requested to be used in this filter. Dimensions cannot be used in this filter." } } }, "MetricMetadata": { "properties": { "category": { "description": "The display name of the category that this metrics belongs to. Similar dimensions and metrics are categorized together.", "type": "string" }, "description": { "type": "string", "description": "Description of how this metric is used and calculated." }, "uiName": { "type": "string", "description": "This metric's name within the Google Analytics user interface. For example, `Event count`." }, "blockedReasons": { "type": "array", "description": "If reasons are specified, your access is blocked to this metric for this property. API requests from you to this property for this metric will succeed; however, the report will contain only zeros for this metric. API requests with metric filters on blocked metrics will fail. If reasons are empty, you have access to this metric. To learn more, see [Access and data-restriction management](https://support.google.com/analytics/answer/10851388).", "items": { "enum": [ "BLOCKED_REASON_UNSPECIFIED", "NO_REVENUE_METRICS", "NO_COST_METRICS" ], "enumDescriptions": [ "Will never be specified in API response.", "If present, your access is blocked to revenue related metrics for this property, and this metric is revenue related.", "If present, your access is blocked to cost related metrics for this property, and this metric is cost related." ], "type": "string" } }, "type": { "description": "The type of this metric.", "type": "string", "enum": [ "METRIC_TYPE_UNSPECIFIED", "TYPE_INTEGER", "TYPE_FLOAT", "TYPE_SECONDS", "TYPE_MILLISECONDS", "TYPE_MINUTES", "TYPE_HOURS", "TYPE_STANDARD", "TYPE_CURRENCY", "TYPE_FEET", "TYPE_MILES", "TYPE_METERS", "TYPE_KILOMETERS" ], "enumDescriptions": [ "Unspecified type.", "Integer type.", "Floating point type.", "A duration of seconds; a special floating point type.", "A duration in milliseconds; a special floating point type.", "A duration in minutes; a special floating point type.", "A duration in hours; a special floating point type.", "A custom metric of standard type; a special floating point type.", "An amount of money; a special floating point type.", "A length in feet; a special floating point type.", "A length in miles; a special floating point type.", "A length in meters; a special floating point type.", "A length in kilometers; a special floating point type." ] }, "apiName": { "description": "A metric name. Useable in [Metric](#Metric)'s `name`. For example, `eventCount`.", "type": "string" }, "customDefinition": { "description": "True if the metric is a custom metric for this property.", "type": "boolean" }, "deprecatedApiNames": { "description": "Still usable but deprecated names for this metric. If populated, this metric is available by either `apiName` or one of `deprecatedApiNames` for a period of time. After the deprecation period, the metric will be available only by `apiName`.", "type": "array", "items": { "type": "string" } }, "expression": { "description": "The mathematical expression for this derived metric. Can be used in [Metric](#Metric)'s `expression` field for equivalent reports. Most metrics are not expressions, and for non-expressions, this field is empty.", "type": "string" } }, "description": "Explains a metric.", "id": "MetricMetadata", "type": "object" }, "BatchRunReportsRequest": { "description": "The batch request containing multiple report requests.", "type": "object", "properties": { "requests": { "items": { "$ref": "RunReportRequest" }, "type": "array", "description": "Individual requests. Each request has a separate report response. Each batch request is allowed up to 5 requests." } }, "id": "BatchRunReportsRequest" }, "DimensionOrderBy": { "id": "DimensionOrderBy", "type": "object", "description": "Sorts by dimension values.", "properties": { "dimensionName": { "description": "A dimension name in the request to order by.", "type": "string" }, "orderType": { "enumDescriptions": [ "Unspecified.", "Alphanumeric sort by Unicode code point. For example, \"2\" \u003c \"A\" \u003c \"X\" \u003c \"b\" \u003c \"z\".", "Case insensitive alphanumeric sort by lower case Unicode code point. For example, \"2\" \u003c \"A\" \u003c \"b\" \u003c \"X\" \u003c \"z\".", "Dimension values are converted to numbers before sorting. For example in NUMERIC sort, \"25\" \u003c \"100\", and in `ALPHANUMERIC` sort, \"100\" \u003c \"25\". Non-numeric dimension values all have equal ordering value below all numeric values." ], "description": "Controls the rule for dimension value ordering.", "enum": [ "ORDER_TYPE_UNSPECIFIED", "ALPHANUMERIC", "CASE_INSENSITIVE_ALPHANUMERIC", "NUMERIC" ], "type": "string" } } }, "FilterExpression": { "description": "To express dimension or metric filters. The fields in the same FilterExpression need to be either all dimensions or all metrics.", "type": "object", "id": "FilterExpression", "properties": { "orGroup": { "description": "The FilterExpressions in or_group have an OR relationship.", "$ref": "FilterExpressionList" }, "andGroup": { "$ref": "FilterExpressionList", "description": "The FilterExpressions in and_group have an AND relationship." }, "notExpression": { "$ref": "FilterExpression", "description": "The FilterExpression is NOT of not_expression." }, "filter": { "$ref": "Filter", "description": "A primitive filter. In the same FilterExpression, all of the filter's field names need to be either all dimensions or all metrics." } } }, "DimensionCompatibility": { "description": "The compatibility for a single dimension.", "id": "DimensionCompatibility", "type": "object", "properties": { "compatibility": { "type": "string", "enumDescriptions": [ "Unspecified compatibility.", "The dimension or metric is compatible. This dimension or metric can be successfully added to a report.", "The dimension or metric is incompatible. This dimension or metric cannot be successfully added to a report." ], "description": "The compatibility of this dimension. If the compatibility is COMPATIBLE, this dimension can be successfully added to the report.", "enum": [ "COMPATIBILITY_UNSPECIFIED", "COMPATIBLE", "INCOMPATIBLE" ] }, "dimensionMetadata": { "description": "The dimension metadata contains the API name for this compatibility information. The dimension metadata also contains other helpful information like the UI name and description.", "$ref": "DimensionMetadata" } } }, "CohortReportSettings": { "id": "CohortReportSettings", "type": "object", "description": "Optional settings of a cohort report.", "properties": { "accumulate": { "description": "If true, accumulates the result from first touch day to the end day. Not supported in `RunReportRequest`.", "type": "boolean" } } }, "MetricValue": { "properties": { "value": { "type": "string", "description": "Measurement value. See MetricHeader for type." } }, "type": "object", "description": "The value of a metric.", "id": "MetricValue" }, "BatchRunReportsResponse": { "id": "BatchRunReportsResponse", "type": "object", "properties": { "kind": { "description": "Identifies what kind of resource this message is. This `kind` is always the fixed string \"analyticsData#batchRunReports\". Useful to distinguish between response types in JSON.", "type": "string" }, "reports": { "description": "Individual responses. Each response has a separate report request.", "items": { "$ref": "RunReportResponse" }, "type": "array" } }, "description": "The batch response containing multiple reports." }, "CheckCompatibilityRequest": { "id": "CheckCompatibilityRequest", "description": "The request for compatibility information for a report's dimensions and metrics. Check compatibility provides a preview of the compatibility of a report; fields shared with the `runReport` request should be the same values as in your `runReport` request.", "properties": { "dimensionFilter": { "description": "The filter clause of dimensions. `dimensionFilter` should be the same value as in your `runReport` request.", "$ref": "FilterExpression" }, "dimensions": { "items": { "$ref": "Dimension" }, "type": "array", "description": "The dimensions in this report. `dimensions` should be the same value as in your `runReport` request." }, "metrics": { "description": "The metrics in this report. `metrics` should be the same value as in your `runReport` request.", "type": "array", "items": { "$ref": "Metric" } }, "metricFilter": { "$ref": "FilterExpression", "description": "The filter clause of metrics. `metricFilter` should be the same value as in your `runReport` request" }, "compatibilityFilter": { "description": "Filters the dimensions and metrics in the response to just this compatibility. Commonly used as `”compatibilityFilter”: “COMPATIBLE”` to only return compatible dimensions & metrics.", "type": "string", "enum": [ "COMPATIBILITY_UNSPECIFIED", "COMPATIBLE", "INCOMPATIBLE" ], "enumDescriptions": [ "Unspecified compatibility.", "The dimension or metric is compatible. This dimension or metric can be successfully added to a report.", "The dimension or metric is incompatible. This dimension or metric cannot be successfully added to a report." ] } }, "type": "object" }, "Pivot": { "type": "object", "properties": { "offset": { "description": "The row count of the start row. The first row is counted as row 0.", "type": "string", "format": "int64" }, "orderBys": { "items": { "$ref": "OrderBy" }, "description": "Specifies how dimensions are ordered in the pivot. In the first Pivot, the OrderBys determine Row and PivotDimensionHeader ordering; in subsequent Pivots, the OrderBys determine only PivotDimensionHeader ordering. Dimensions specified in these OrderBys must be a subset of Pivot.field_names.", "type": "array" }, "limit": { "description": "The number of unique combinations of dimension values to return in this pivot. The `limit` parameter is required. A `limit` of 10,000 is common for single pivot requests. The product of the `limit` for each `pivot` in a `RunPivotReportRequest` must not exceed 100,000. For example, a two pivot request with `limit: 1000` in each pivot will fail because the product is `1,000,000`.", "type": "string", "format": "int64" }, "metricAggregations": { "items": { "type": "string", "enumDescriptions": [ "Unspecified operator.", "SUM operator.", "Minimum operator.", "Maximum operator.", "Count operator." ], "enum": [ "METRIC_AGGREGATION_UNSPECIFIED", "TOTAL", "MINIMUM", "MAXIMUM", "COUNT" ] }, "type": "array", "description": "Aggregate the metrics by dimensions in this pivot using the specified metric_aggregations." }, "fieldNames": { "items": { "type": "string" }, "description": "Dimension names for visible columns in the report response. Including \"dateRange\" produces a date range column; for each row in the response, dimension values in the date range column will indicate the corresponding date range from the request.", "type": "array" } }, "id": "Pivot", "description": "Describes the visible dimension columns and rows in the report response." }, "RunReportResponse": { "description": "The response report table corresponding to a request.", "type": "object", "id": "RunReportResponse", "properties": { "minimums": { "items": { "$ref": "Row" }, "type": "array", "description": "If requested, the minimum values of metrics." }, "dimensionHeaders": { "type": "array", "description": "Describes dimension columns. The number of DimensionHeaders and ordering of DimensionHeaders matches the dimensions present in rows.", "items": { "$ref": "DimensionHeader" } }, "metricHeaders": { "description": "Describes metric columns. The number of MetricHeaders and ordering of MetricHeaders matches the metrics present in rows.", "type": "array", "items": { "$ref": "MetricHeader" } }, "metadata": { "description": "Metadata for the report.", "$ref": "ResponseMetaData" }, "totals": { "type": "array", "items": { "$ref": "Row" }, "description": "If requested, the totaled values of metrics." }, "propertyQuota": { "description": "This Analytics Property's quota state including this request.", "$ref": "PropertyQuota" }, "maximums": { "description": "If requested, the maximum values of metrics.", "items": { "$ref": "Row" }, "type": "array" }, "kind": { "description": "Identifies what kind of resource this message is. This `kind` is always the fixed string \"analyticsData#runReport\". Useful to distinguish between response types in JSON.", "type": "string" }, "rows": { "items": { "$ref": "Row" }, "type": "array", "description": "Rows of dimension value combinations and metric values in the report." }, "rowCount": { "description": "The total number of rows in the query result. `rowCount` is independent of the number of rows returned in the response, the `limit` request parameter, and the `offset` request parameter. For example if a query returns 175 rows and includes `limit` of 50 in the API request, the response will contain `rowCount` of 175 but only 50 rows. To learn more about this pagination parameter, see [Pagination](https://developers.google.com/analytics/devguides/reporting/data/v1/basics#pagination).", "type": "integer", "format": "int32" } } }, "ActiveMetricRestriction": { "type": "object", "description": "A metric actively restricted in creating the report.", "id": "ActiveMetricRestriction", "properties": { "metricName": { "type": "string", "description": "The name of the restricted metric." }, "restrictedMetricTypes": { "items": { "enumDescriptions": [ "Unspecified type.", "Cost metrics such as `adCost`.", "Revenue metrics such as `purchaseRevenue`." ], "type": "string", "enum": [ "RESTRICTED_METRIC_TYPE_UNSPECIFIED", "COST_DATA", "REVENUE_DATA" ] }, "description": "The reason for this metric's restriction.", "type": "array" } } }, "FilterExpressionList": { "properties": { "expressions": { "type": "array", "description": "A list of filter expressions.", "items": { "$ref": "FilterExpression" } } }, "id": "FilterExpressionList", "description": "A list of filter expressions.", "type": "object" }, "RunRealtimeReportRequest": { "id": "RunRealtimeReportRequest", "properties": { "metrics": { "type": "array", "items": { "$ref": "Metric" }, "description": "The metrics requested and displayed." }, "dimensions": { "type": "array", "description": "The dimensions requested and displayed.", "items": { "$ref": "Dimension" } }, "returnPropertyQuota": { "type": "boolean", "description": "Toggles whether to return the current state of this Analytics Property's Realtime quota. Quota is returned in [PropertyQuota](#PropertyQuota)." }, "minuteRanges": { "type": "array", "items": { "$ref": "MinuteRange" }, "description": "The minute ranges of event data to read. If unspecified, one minute range for the last 30 minutes will be used. If multiple minute ranges are requested, each response row will contain a zero based minute range index. If two minute ranges overlap, the event data for the overlapping minutes is included in the response rows for both minute ranges." }, "orderBys": { "type": "array", "description": "Specifies how rows are ordered in the response.", "items": { "$ref": "OrderBy" } }, "dimensionFilter": { "description": "The filter clause of dimensions. Metrics cannot be used in this filter.", "$ref": "FilterExpression" }, "metricAggregations": { "type": "array", "items": { "enum": [ "METRIC_AGGREGATION_UNSPECIFIED", "TOTAL", "MINIMUM", "MAXIMUM", "COUNT" ], "type": "string", "enumDescriptions": [ "Unspecified operator.", "SUM operator.", "Minimum operator.", "Maximum operator.", "Count operator." ] }, "description": "Aggregation of metrics. Aggregated metric values will be shown in rows where the dimension_values are set to \"RESERVED_(MetricAggregation)\"." }, "metricFilter": { "description": "The filter clause of metrics. Applied at post aggregation phase, similar to SQL having-clause. Dimensions cannot be used in this filter.", "$ref": "FilterExpression" }, "limit": { "type": "string", "description": "The number of rows to return. If unspecified, 10,000 rows are returned. The API returns a maximum of 100,000 rows per request, no matter how many you ask for. `limit` must be positive. The API can also return fewer rows than the requested `limit`, if there aren't as many dimension values as the `limit`. For instance, there are fewer than 300 possible values for the dimension `country`, so when reporting on only `country`, you can't get more than 300 rows, even if you set `limit` to a higher value.", "format": "int64" } }, "description": "The request to generate a realtime report.", "type": "object" }, "DimensionMetadata": { "type": "object", "description": "Explains a dimension.", "properties": { "deprecatedApiNames": { "items": { "type": "string" }, "type": "array", "description": "Still usable but deprecated names for this dimension. If populated, this dimension is available by either `apiName` or one of `deprecatedApiNames` for a period of time. After the deprecation period, the dimension will be available only by `apiName`." }, "category": { "type": "string", "description": "The display name of the category that this dimension belongs to. Similar dimensions and metrics are categorized together." }, "apiName": { "type": "string", "description": "This dimension's name. Useable in [Dimension](#Dimension)'s `name`. For example, `eventName`." }, "customDefinition": { "type": "boolean", "description": "True if the dimension is a custom dimension for this property." }, "uiName": { "description": "This dimension's name within the Google Analytics user interface. For example, `Event name`.", "type": "string" }, "description": { "type": "string", "description": "Description of how this dimension is used and calculated." } }, "id": "DimensionMetadata" }, "SchemaRestrictionResponse": { "id": "SchemaRestrictionResponse", "description": "The schema restrictions actively enforced in creating this report. To learn more, see [Access and data-restriction management](https://support.google.com/analytics/answer/10851388).", "type": "object", "properties": { "activeMetricRestrictions": { "type": "array", "items": { "$ref": "ActiveMetricRestriction" }, "description": "All restrictions actively enforced in creating the report. For example, `purchaseRevenue` always has the restriction type `REVENUE_DATA`. However, this active response restriction is only populated if the user's custom role disallows access to `REVENUE_DATA`." } } }, "BatchRunPivotReportsResponse": { "properties": { "kind": { "type": "string", "description": "Identifies what kind of resource this message is. This `kind` is always the fixed string \"analyticsData#batchRunPivotReports\". Useful to distinguish between response types in JSON." }, "pivotReports": { "items": { "$ref": "RunPivotReportResponse" }, "description": "Individual responses. Each response has a separate pivot report request.", "type": "array" } }, "id": "BatchRunPivotReportsResponse", "description": "The batch response containing multiple pivot reports.", "type": "object" }, "OrderBy": { "type": "object", "properties": { "desc": { "type": "boolean", "description": "If true, sorts by descending order." }, "pivot": { "description": "Sorts results by a metric's values within a pivot column group.", "$ref": "PivotOrderBy" }, "metric": { "description": "Sorts results by a metric's values.", "$ref": "MetricOrderBy" }, "dimension": { "$ref": "DimensionOrderBy", "description": "Sorts results by a dimension's values." } }, "id": "OrderBy", "description": "Order bys define how rows will be sorted in the response. For example, ordering rows by descending event count is one ordering, and ordering rows by the event name string is a different ordering." }, "ConcatenateExpression": { "type": "object", "description": "Used to combine dimension values to a single dimension.", "properties": { "delimiter": { "type": "string", "description": "The delimiter placed between dimension names. Delimiters are often single characters such as \"|\" or \",\" but can be longer strings. If a dimension value contains the delimiter, both will be present in response with no distinction. For example if dimension 1 value = \"US,FR\", dimension 2 value = \"JP\", and delimiter = \",\", then the response will contain \"US,FR,JP\"." }, "dimensionNames": { "items": { "type": "string" }, "type": "array", "description": "Names of dimensions. The names must refer back to names in the dimensions field of the request." } }, "id": "ConcatenateExpression" }, "DimensionExpression": { "properties": { "lowerCase": { "$ref": "CaseExpression", "description": "Used to convert a dimension value to lower case." }, "upperCase": { "$ref": "CaseExpression", "description": "Used to convert a dimension value to upper case." }, "concatenate": { "description": "Used to combine dimension values to a single dimension. For example, dimension \"country, city\": concatenate(country, \", \", city).", "$ref": "ConcatenateExpression" } }, "type": "object", "description": "Used to express a dimension which is the result of a formula of multiple dimensions. Example usages: 1) lower_case(dimension) 2) concatenate(dimension1, symbol, dimension2).", "id": "DimensionExpression" }, "PivotSelection": { "description": "A pair of dimension names and values. Rows with this dimension pivot pair are ordered by the metric's value. For example if pivots = {{\"browser\", \"Chrome\"}} and metric_name = \"Sessions\", then the rows will be sorted based on Sessions in Chrome. ---------|----------|----------------|----------|---------------- | Chrome | Chrome | Safari | Safari ---------|----------|----------------|----------|---------------- Country | Sessions | Pages/Sessions | Sessions | Pages/Sessions ---------|----------|----------------|----------|---------------- US | 2 | 2 | 3 | 1 ---------|----------|----------------|----------|---------------- Canada | 3 | 1 | 4 | 1 ---------|----------|----------------|----------|----------------", "type": "object", "id": "PivotSelection", "properties": { "dimensionName": { "type": "string", "description": "Must be a dimension name from the request." }, "dimensionValue": { "description": "Order by only when the named dimension is this value.", "type": "string" } } }, "BatchRunPivotReportsRequest": { "description": "The batch request containing multiple pivot report requests.", "properties": { "requests": { "type": "array", "items": { "$ref": "RunPivotReportRequest" }, "description": "Individual requests. Each request has a separate pivot report response. Each batch request is allowed up to 5 requests." } }, "type": "object", "id": "BatchRunPivotReportsRequest" }, "PivotDimensionHeader": { "description": "Summarizes dimension values from a row for this pivot.", "type": "object", "properties": { "dimensionValues": { "items": { "$ref": "DimensionValue" }, "description": "Values of multiple dimensions in a pivot.", "type": "array" } }, "id": "PivotDimensionHeader" }, "PivotHeader": { "properties": { "pivotDimensionHeaders": { "type": "array", "description": "The size is the same as the cardinality of the corresponding dimension combinations.", "items": { "$ref": "PivotDimensionHeader" } }, "rowCount": { "type": "integer", "description": "The cardinality of the pivot. The total number of rows for this pivot's fields regardless of how the parameters `offset` and `limit` are specified in the request.", "format": "int32" } }, "id": "PivotHeader", "type": "object", "description": "Dimensions' values in a single pivot." }, "RunPivotReportResponse": { "id": "RunPivotReportResponse", "type": "object", "description": "The response pivot report table corresponding to a pivot request.", "properties": { "propertyQuota": { "description": "This Analytics Property's quota state including this request.", "$ref": "PropertyQuota" }, "rows": { "description": "Rows of dimension value combinations and metric values in the report.", "items": { "$ref": "Row" }, "type": "array" }, "pivotHeaders": { "items": { "$ref": "PivotHeader" }, "description": "Summarizes the columns and rows created by a pivot. Each pivot in the request produces one header in the response. If we have a request like this: \"pivots\": [{ \"fieldNames\": [\"country\", \"city\"] }, { \"fieldNames\": \"eventName\" }] We will have the following `pivotHeaders` in the response: \"pivotHeaders\" : [{ \"dimensionHeaders\": [{ \"dimensionValues\": [ { \"value\": \"United Kingdom\" }, { \"value\": \"London\" } ] }, { \"dimensionValues\": [ { \"value\": \"Japan\" }, { \"value\": \"Osaka\" } ] }] }, { \"dimensionHeaders\": [{ \"dimensionValues\": [{ \"value\": \"session_start\" }] }, { \"dimensionValues\": [{ \"value\": \"scroll\" }] }] }]", "type": "array" }, "aggregates": { "description": "Aggregation of metric values. Can be totals, minimums, or maximums. The returned aggregations are controlled by the metric_aggregations in the pivot. The type of aggregation returned in each row is shown by the dimension_values which are set to \"RESERVED_\".", "type": "array", "items": { "$ref": "Row" } }, "kind": { "description": "Identifies what kind of resource this message is. This `kind` is always the fixed string \"analyticsData#runPivotReport\". Useful to distinguish between response types in JSON.", "type": "string" }, "metadata": { "$ref": "ResponseMetaData", "description": "Metadata for the report." }, "metricHeaders": { "description": "Describes metric columns. The number of MetricHeaders and ordering of MetricHeaders matches the metrics present in rows.", "items": { "$ref": "MetricHeader" }, "type": "array" }, "dimensionHeaders": { "description": "Describes dimension columns. The number of DimensionHeaders and ordering of DimensionHeaders matches the dimensions present in rows.", "items": { "$ref": "DimensionHeader" }, "type": "array" } } }, "Metric": { "description": "The quantitative measurements of a report. For example, the metric `eventCount` is the total number of events. Requests are allowed up to 10 metrics.", "type": "object", "properties": { "invisible": { "type": "boolean", "description": "Indicates if a metric is invisible in the report response. If a metric is invisible, the metric will not produce a column in the response, but can be used in `metricFilter`, `orderBys`, or a metric `expression`." }, "expression": { "type": "string", "description": "A mathematical expression for derived metrics. For example, the metric Event count per user is `eventCount/totalUsers`." }, "name": { "type": "string", "description": "The name of the metric. See the [API Metrics](https://developers.google.com/analytics/devguides/reporting/data/v1/api-schema#metrics) for the list of metric names. If `expression` is specified, `name` can be any string that you would like within the allowed character set. For example if `expression` is `screenPageViews/sessions`, you could call that metric's name = `viewsPerSession`. Metric names that you choose must match the regular expression `^[a-zA-Z0-9_]$`. Metrics are referenced by `name` in `metricFilter`, `orderBys`, and metric `expression`." } }, "id": "Metric" }, "CohortsRange": { "id": "CohortsRange", "description": "Configures the extended reporting date range for a cohort report. Specifies an offset duration to follow the cohorts over.", "type": "object", "properties": { "granularity": { "type": "string", "enum": [ "GRANULARITY_UNSPECIFIED", "DAILY", "WEEKLY", "MONTHLY" ], "description": "Required. The granularity used to interpret the `startOffset` and `endOffset` for the extended reporting date range for a cohort report.", "enumDescriptions": [ "Should never be specified.", "Daily granularity. Commonly used if the cohort's `dateRange` is a single day and the request contains `cohortNthDay`.", "Weekly granularity. Commonly used if the cohort's `dateRange` is a week in duration (starting on Sunday and ending on Saturday) and the request contains `cohortNthWeek`.", "Monthly granularity. Commonly used if the cohort's `dateRange` is a month in duration and the request contains `cohortNthMonth`." ] }, "startOffset": { "type": "integer", "format": "int32", "description": "`startOffset` specifies the start date of the extended reporting date range for a cohort report. `startOffset` is commonly set to 0 so that reports contain data from the acquisition of the cohort forward. If `granularity` is `DAILY`, the `startDate` of the extended reporting date range is `startDate` of the cohort plus `startOffset` days. If `granularity` is `WEEKLY`, the `startDate` of the extended reporting date range is `startDate` of the cohort plus `startOffset LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh 7` days. If `granularity` is `MONTHLY`, the `startDate` of the extended reporting date range is `startDate` of the cohort plus `startOffset LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh 30` days." }, "endOffset": { "description": "Required. `endOffset` specifies the end date of the extended reporting date range for a cohort report. `endOffset` can be any positive integer but is commonly set to 5 to 10 so that reports contain data on the cohort for the next several granularity time periods. If `granularity` is `DAILY`, the `endDate` of the extended reporting date range is `endDate` of the cohort plus `endOffset` days. If `granularity` is `WEEKLY`, the `endDate` of the extended reporting date range is `endDate` of the cohort plus `endOffset LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh 7` days. If `granularity` is `MONTHLY`, the `endDate` of the extended reporting date range is `endDate` of the cohort plus `endOffset LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh 30` days.", "type": "integer", "format": "int32" } } }, "CheckCompatibilityResponse": { "description": "The compatibility response with the compatibility of each dimension & metric.", "id": "CheckCompatibilityResponse", "type": "object", "properties": { "dimensionCompatibilities": { "items": { "$ref": "DimensionCompatibility" }, "type": "array", "description": "The compatibility of each dimension." }, "metricCompatibilities": { "description": "The compatibility of each metric.", "type": "array", "items": { "$ref": "MetricCompatibility" } } } }, "PropertyQuota": { "properties": { "serverErrorsPerProjectPerHour": { "description": "Standard Analytics Properties and cloud project pairs can have up to 10 server errors per hour; Analytics 360 Properties and cloud project pairs can have up to 50 server errors per hour.", "$ref": "QuotaStatus" }, "tokensPerDay": { "description": "Standard Analytics Properties can use up to 25,000 tokens per day; Analytics 360 Properties can use 250,000 tokens per day. Most requests consume fewer than 10 tokens.", "$ref": "QuotaStatus" }, "concurrentRequests": { "$ref": "QuotaStatus", "description": "Standard Analytics Properties can send up to 10 concurrent requests; Analytics 360 Properties can use up to 50 concurrent requests." }, "potentiallyThresholdedRequestsPerHour": { "$ref": "QuotaStatus", "description": "Analytics Properties can send up to 120 requests with potentially thresholded dimensions per hour. In a batch request, each report request is individually counted for this quota if the request contains potentially thresholded dimensions." }, "tokensPerHour": { "$ref": "QuotaStatus", "description": "Standard Analytics Properties can use up to 5,000 tokens per hour; Analytics 360 Properties can use 50,000 tokens per hour. An API request consumes a single number of tokens, and that number is deducted from both the hourly and daily quotas." } }, "id": "PropertyQuota", "description": "Current state of all quotas for this Analytics Property. If any quota for a property is exhausted, all requests to that property will return Resource Exhausted errors.", "type": "object" }, "QuotaStatus": { "type": "object", "description": "Current state for a particular quota group.", "properties": { "remaining": { "format": "int32", "type": "integer", "description": "Quota remaining after this request." }, "consumed": { "type": "integer", "format": "int32", "description": "Quota consumed by this request." } }, "id": "QuotaStatus" }, "DateRange": { "description": "A contiguous set of days: startDate, startDate + 1, ..., endDate. Requests are allowed up to 4 date ranges.", "type": "object", "properties": { "name": { "description": "Assigns a name to this date range. The dimension `dateRange` is valued to this name in a report response. If set, cannot begin with `date_range_` or `RESERVED_`. If not set, date ranges are named by their zero based index in the request: `date_range_0`, `date_range_1`, etc.", "type": "string" }, "endDate": { "description": "The inclusive end date for the query in the format `YYYY-MM-DD`. Cannot be before `start_date`. The format `NdaysAgo`, `yesterday`, or `today` is also accepted, and in that case, the date is inferred based on the property's reporting time zone.", "type": "string" }, "startDate": { "description": "The inclusive start date for the query in the format `YYYY-MM-DD`. Cannot be after `end_date`. The format `NdaysAgo`, `yesterday`, or `today` is also accepted, and in that case, the date is inferred based on the property's reporting time zone.", "type": "string" } }, "id": "DateRange" }, "StringFilter": { "id": "StringFilter", "type": "object", "properties": { "matchType": { "description": "The match type for this filter.", "enum": [ "MATCH_TYPE_UNSPECIFIED", "EXACT", "BEGINS_WITH", "ENDS_WITH", "CONTAINS", "FULL_REGEXP", "PARTIAL_REGEXP" ], "type": "string", "enumDescriptions": [ "Unspecified", "Exact match of the string value.", "Begins with the string value.", "Ends with the string value.", "Contains the string value.", "Full match for the regular expression with the string value.", "Partial match for the regular expression with the string value." ] }, "caseSensitive": { "type": "boolean", "description": "If true, the string value is case sensitive." }, "value": { "type": "string", "description": "The string value used for the matching." } }, "description": "The filter for string" }, "RunReportRequest": { "properties": { "metrics": { "items": { "$ref": "Metric" }, "type": "array", "description": "The metrics requested and displayed." }, "dimensionFilter": { "description": "Dimension filters allow you to ask for only specific dimension values in the report. To learn more, see [Fundamentals of Dimension Filters](https://developers.google.com/analytics/devguides/reporting/data/v1/basics#dimension_filters) for examples. Metrics cannot be used in this filter.", "$ref": "FilterExpression" }, "keepEmptyRows": { "type": "boolean", "description": "If false or unspecified, each row with all metrics equal to 0 will not be returned. If true, these rows will be returned if they are not separately removed by a filter." }, "limit": { "description": "The number of rows to return. If unspecified, 10,000 rows are returned. The API returns a maximum of 100,000 rows per request, no matter how many you ask for. `limit` must be positive. The API can also return fewer rows than the requested `limit`, if there aren't as many dimension values as the `limit`. For instance, there are fewer than 300 possible values for the dimension `country`, so when reporting on only `country`, you can't get more than 300 rows, even if you set `limit` to a higher value. To learn more about this pagination parameter, see [Pagination](https://developers.google.com/analytics/devguides/reporting/data/v1/basics#pagination).", "format": "int64", "type": "string" }, "offset": { "format": "int64", "description": "The row count of the start row. The first row is counted as row 0. When paging, the first request does not specify offset; or equivalently, sets offset to 0; the first request returns the first `limit` of rows. The second request sets offset to the `limit` of the first request; the second request returns the second `limit` of rows. To learn more about this pagination parameter, see [Pagination](https://developers.google.com/analytics/devguides/reporting/data/v1/basics#pagination).", "type": "string" }, "metricFilter": { "description": "The filter clause of metrics. Applied after aggregating the report's rows, similar to SQL having-clause. Dimensions cannot be used in this filter.", "$ref": "FilterExpression" }, "orderBys": { "description": "Specifies how rows are ordered in the response.", "items": { "$ref": "OrderBy" }, "type": "array" }, "currencyCode": { "description": "A currency code in ISO4217 format, such as \"AED\", \"USD\", \"JPY\". If the field is empty, the report uses the property's default currency.", "type": "string" }, "dimensions": { "description": "The dimensions requested and displayed.", "type": "array", "items": { "$ref": "Dimension" } }, "property": { "description": "A Google Analytics GA4 property identifier whose events are tracked. Specified in the URL path and not the body. To learn more, see [where to find your Property ID](https://developers.google.com/analytics/devguides/reporting/data/v1/property-id). Within a batch request, this property should either be unspecified or consistent with the batch-level property. Example: properties/1234", "type": "string" }, "cohortSpec": { "description": "Cohort group associated with this request. If there is a cohort group in the request the 'cohort' dimension must be present.", "$ref": "CohortSpec" }, "dateRanges": { "type": "array", "description": "Date ranges of data to read. If multiple date ranges are requested, each response row will contain a zero based date range index. If two date ranges overlap, the event data for the overlapping days is included in the response rows for both date ranges. In a cohort request, this `dateRanges` must be unspecified.", "items": { "$ref": "DateRange" } }, "returnPropertyQuota": { "description": "Toggles whether to return the current state of this Analytics Property's quota. Quota is returned in [PropertyQuota](#PropertyQuota).", "type": "boolean" }, "metricAggregations": { "items": { "type": "string", "enumDescriptions": [ "Unspecified operator.", "SUM operator.", "Minimum operator.", "Maximum operator.", "Count operator." ], "enum": [ "METRIC_AGGREGATION_UNSPECIFIED", "TOTAL", "MINIMUM", "MAXIMUM", "COUNT" ] }, "description": "Aggregation of metrics. Aggregated metric values will be shown in rows where the dimension_values are set to \"RESERVED_(MetricAggregation)\".", "type": "array" } }, "id": "RunReportRequest", "type": "object", "description": "The request to generate a report." }, "Metadata": { "properties": { "metrics": { "description": "The metric descriptions.", "type": "array", "items": { "$ref": "MetricMetadata" } }, "dimensions": { "type": "array", "description": "The dimension descriptions.", "items": { "$ref": "DimensionMetadata" } }, "name": { "type": "string", "description": "Resource name of this metadata." } }, "description": "The dimensions and metrics currently accepted in reporting methods.", "type": "object", "id": "Metadata" }, "CaseExpression": { "type": "object", "id": "CaseExpression", "properties": { "dimensionName": { "description": "Name of a dimension. The name must refer back to a name in dimensions field of the request.", "type": "string" } }, "description": "Used to convert a dimension value to a single case." }, "PivotOrderBy": { "properties": { "pivotSelections": { "items": { "$ref": "PivotSelection" }, "description": "Used to select a dimension name and value pivot. If multiple pivot selections are given, the sort occurs on rows where all pivot selection dimension name and value pairs match the row's dimension name and value pair.", "type": "array" }, "metricName": { "description": "In the response to order by, order rows by this column. Must be a metric name from the request.", "type": "string" } }, "type": "object", "description": "Sorts by a pivot column group.", "id": "PivotOrderBy" }, "Dimension": { "description": "Dimensions are attributes of your data. For example, the dimension city indicates the city from which an event originates. Dimension values in report responses are strings; for example, the city could be \"Paris\" or \"New York\". Requests are allowed up to 9 dimensions.", "properties": { "dimensionExpression": { "$ref": "DimensionExpression", "description": "One dimension can be the result of an expression of multiple dimensions. For example, dimension \"country, city\": concatenate(country, \", \", city)." }, "name": { "type": "string", "description": "The name of the dimension. See the [API Dimensions](https://developers.google.com/analytics/devguides/reporting/data/v1/api-schema#dimensions) for the list of dimension names. If `dimensionExpression` is specified, `name` can be any string that you would like within the allowed character set. For example if a `dimensionExpression` concatenates `country` and `city`, you could call that dimension `countryAndCity`. Dimension names that you choose must match the regular expression `^[a-zA-Z0-9_]$`. Dimensions are referenced by `name` in `dimensionFilter`, `orderBys`, `dimensionExpression`, and `pivots`." } }, "type": "object", "id": "Dimension" }, "RunRealtimeReportResponse": { "properties": { "dimensionHeaders": { "description": "Describes dimension columns. The number of DimensionHeaders and ordering of DimensionHeaders matches the dimensions present in rows.", "type": "array", "items": { "$ref": "DimensionHeader" } }, "metricHeaders": { "items": { "$ref": "MetricHeader" }, "type": "array", "description": "Describes metric columns. The number of MetricHeaders and ordering of MetricHeaders matches the metrics present in rows." }, "maximums": { "items": { "$ref": "Row" }, "description": "If requested, the maximum values of metrics.", "type": "array" }, "kind": { "type": "string", "description": "Identifies what kind of resource this message is. This `kind` is always the fixed string \"analyticsData#runRealtimeReport\". Useful to distinguish between response types in JSON." }, "minimums": { "items": { "$ref": "Row" }, "type": "array", "description": "If requested, the minimum values of metrics." }, "propertyQuota": { "$ref": "PropertyQuota", "description": "This Analytics Property's Realtime quota state including this request." }, "rows": { "items": { "$ref": "Row" }, "type": "array", "description": "Rows of dimension value combinations and metric values in the report." }, "rowCount": { "format": "int32", "description": "The total number of rows in the query result. `rowCount` is independent of the number of rows returned in the response and the `limit` request parameter. For example if a query returns 175 rows and includes `limit` of 50 in the API request, the response will contain `rowCount` of 175 but only 50 rows.", "type": "integer" }, "totals": { "items": { "$ref": "Row" }, "type": "array", "description": "If requested, the totaled values of metrics." } }, "description": "The response realtime report table corresponding to a request.", "id": "RunRealtimeReportResponse", "type": "object" }, "BetweenFilter": { "id": "BetweenFilter", "properties": { "toValue": { "description": "Ends with this number.", "$ref": "NumericValue" }, "fromValue": { "description": "Begins with this number.", "$ref": "NumericValue" } }, "type": "object", "description": "To express that the result needs to be between two numbers (inclusive)." }, "MetricCompatibility": { "description": "The compatibility for a single metric.", "properties": { "compatibility": { "description": "The compatibility of this metric. If the compatibility is COMPATIBLE, this metric can be successfully added to the report.", "enum": [ "COMPATIBILITY_UNSPECIFIED", "COMPATIBLE", "INCOMPATIBLE" ], "type": "string", "enumDescriptions": [ "Unspecified compatibility.", "The dimension or metric is compatible. This dimension or metric can be successfully added to a report.", "The dimension or metric is incompatible. This dimension or metric cannot be successfully added to a report." ] }, "metricMetadata": { "description": "The metric metadata contains the API name for this compatibility information. The metric metadata also contains other helpful information like the UI name and description.", "$ref": "MetricMetadata" } }, "id": "MetricCompatibility", "type": "object" }, "MetricOrderBy": { "description": "Sorts by metric values.", "id": "MetricOrderBy", "type": "object", "properties": { "metricName": { "type": "string", "description": "A metric name in the request to order by." } } }, "MinuteRange": { "description": "A contiguous set of minutes: startMinutesAgo, startMinutesAgo + 1, ..., endMinutesAgo. Requests are allowed up to 2 minute ranges.", "id": "MinuteRange", "type": "object", "properties": { "startMinutesAgo": { "description": "The inclusive start minute for the query as a number of minutes before now. For example, `\"startMinutesAgo\": 29` specifies the report should include event data from 29 minutes ago and after. Cannot be after `endMinutesAgo`. If unspecified, `startMinutesAgo` is defaulted to 29. Standard Analytics properties can request up to the last 30 minutes of event data (`startMinutesAgo \u003c= 29`), and 360 Analytics properties can request up to the last 60 minutes of event data (`startMinutesAgo \u003c= 59`).", "format": "int32", "type": "integer" }, "endMinutesAgo": { "description": "The inclusive end minute for the query as a number of minutes before now. Cannot be before `startMinutesAgo`. For example, `\"endMinutesAgo\": 15` specifies the report should include event data from prior to 15 minutes ago. If unspecified, `endMinutesAgo` is defaulted to 0. Standard Analytics properties can request any minute in the last 30 minutes of event data (`endMinutesAgo \u003c= 29`), and 360 Analytics properties can request any minute in the last 60 minutes of event data (`endMinutesAgo \u003c= 59`).", "type": "integer", "format": "int32" }, "name": { "type": "string", "description": "Assigns a name to this minute range. The dimension `dateRange` is valued to this name in a report response. If set, cannot begin with `date_range_` or `RESERVED_`. If not set, minute ranges are named by their zero based index in the request: `date_range_0`, `date_range_1`, etc." } } }, "MetricHeader": { "id": "MetricHeader", "description": "Describes a metric column in the report. Visible metrics requested in a report produce column entries within rows and MetricHeaders. However, metrics used exclusively within filters or expressions do not produce columns in a report; correspondingly, those metrics do not produce headers.", "properties": { "name": { "type": "string", "description": "The metric's name." }, "type": { "description": "The metric's data type.", "enumDescriptions": [ "Unspecified type.", "Integer type.", "Floating point type.", "A duration of seconds; a special floating point type.", "A duration in milliseconds; a special floating point type.", "A duration in minutes; a special floating point type.", "A duration in hours; a special floating point type.", "A custom metric of standard type; a special floating point type.", "An amount of money; a special floating point type.", "A length in feet; a special floating point type.", "A length in miles; a special floating point type.", "A length in meters; a special floating point type.", "A length in kilometers; a special floating point type." ], "enum": [ "METRIC_TYPE_UNSPECIFIED", "TYPE_INTEGER", "TYPE_FLOAT", "TYPE_SECONDS", "TYPE_MILLISECONDS", "TYPE_MINUTES", "TYPE_HOURS", "TYPE_STANDARD", "TYPE_CURRENCY", "TYPE_FEET", "TYPE_MILES", "TYPE_METERS", "TYPE_KILOMETERS" ], "type": "string" } }, "type": "object" }, "NumericFilter": { "id": "NumericFilter", "type": "object", "description": "Filters for numeric or date values.", "properties": { "operation": { "enum": [ "OPERATION_UNSPECIFIED", "EQUAL", "LESS_THAN", "LESS_THAN_OR_EQUAL", "GREATER_THAN", "GREATER_THAN_OR_EQUAL" ], "description": "The operation type for this filter.", "type": "string", "enumDescriptions": [ "Unspecified.", "Equal", "Less than", "Less than or equal", "Greater than", "Greater than or equal" ] }, "value": { "description": "A numeric value or a date value.", "$ref": "NumericValue" } } }, "DimensionHeader": { "id": "DimensionHeader", "description": "Describes a dimension column in the report. Dimensions requested in a report produce column entries within rows and DimensionHeaders. However, dimensions used exclusively within filters or expressions do not produce columns in a report; correspondingly, those dimensions do not produce headers.", "properties": { "name": { "type": "string", "description": "The dimension's name." } }, "type": "object" }, "DimensionValue": { "id": "DimensionValue", "properties": { "value": { "type": "string", "description": "Value as a string if the dimension type is a string." } }, "type": "object", "description": "The value of a dimension." } }, "name": "analyticsdata", "icons": { "x32": "http://www.google.com/images/icons/product/search-32.gif", "x16": "http://www.google.com/images/icons/product/search-16.gif" }, "description": "Accesses report data in Google Analytics.", "basePath": "", "servicePath": "", "discoveryVersion": "v1", "resources": { "properties": { "methods": { "runRealtimeReport": { "description": "Returns a customized report of realtime event data for your property. Events appear in realtime reports seconds after they have been sent to the Google Analytics. Realtime reports show events and usage data for the periods of time ranging from the present moment to 30 minutes ago (up to 60 minutes for Google Analytics 360 properties). For a guide to constructing realtime requests & understanding responses, see [Creating a Realtime Report](https://developers.google.com/analytics/devguides/reporting/data/v1/realtime-basics).", "path": "v1beta/{+property}:runRealtimeReport", "id": "analyticsdata.properties.runRealtimeReport", "scopes": [ "https://www.googleapis.com/auth/analytics", "https://www.googleapis.com/auth/analytics.readonly" ], "request": { "$ref": "RunRealtimeReportRequest" }, "parameterOrder": [ "property" ], "httpMethod": "POST", "response": { "$ref": "RunRealtimeReportResponse" }, "parameters": { "property": { "required": true, "type": "string", "description": "A Google Analytics GA4 property identifier whose events are tracked. Specified in the URL path and not the body. To learn more, see [where to find your Property ID](https://developers.google.com/analytics/devguides/reporting/data/v1/property-id). Example: properties/1234", "location": "path", "pattern": "^properties/[^/]+$" } }, "flatPath": "v1beta/properties/{propertiesId}:runRealtimeReport" }, "getMetadata": { "httpMethod": "GET", "path": "v1beta/{+name}", "parameterOrder": [ "name" ], "scopes": [ "https://www.googleapis.com/auth/analytics", "https://www.googleapis.com/auth/analytics.readonly" ], "parameters": { "name": { "pattern": "^properties/[^/]+/metadata$", "type": "string", "description": "Required. The resource name of the metadata to retrieve. This name field is specified in the URL path and not URL parameters. Property is a numeric Google Analytics GA4 Property identifier. To learn more, see [where to find your Property ID](https://developers.google.com/analytics/devguides/reporting/data/v1/property-id). Example: properties/1234/metadata Set the Property ID to 0 for dimensions and metrics common to all properties. In this special mode, this method will not return custom dimensions and metrics.", "location": "path", "required": true } }, "response": { "$ref": "Metadata" }, "description": "Returns metadata for dimensions and metrics available in reporting methods. Used to explore the dimensions and metrics. In this method, a Google Analytics GA4 Property Identifier is specified in the request, and the metadata response includes Custom dimensions and metrics as well as Universal metadata. For example if a custom metric with parameter name `levels_unlocked` is registered to a property, the Metadata response will contain `customEvent:levels_unlocked`. Universal metadata are dimensions and metrics applicable to any property such as `country` and `totalUsers`.", "flatPath": "v1beta/properties/{propertiesId}/metadata", "id": "analyticsdata.properties.getMetadata" }, "checkCompatibility": { "scopes": [ "https://www.googleapis.com/auth/analytics", "https://www.googleapis.com/auth/analytics.readonly" ], "flatPath": "v1beta/properties/{propertiesId}:checkCompatibility", "response": { "$ref": "CheckCompatibilityResponse" }, "httpMethod": "POST", "description": "This compatibility method lists dimensions and metrics that can be added to a report request and maintain compatibility. This method fails if the request's dimensions and metrics are incompatible. In Google Analytics, reports fail if they request incompatible dimensions and/or metrics; in that case, you will need to remove dimensions and/or metrics from the incompatible report until the report is compatible. The Realtime and Core reports have different compatibility rules. This method checks compatibility for Core reports.", "parameterOrder": [ "property" ], "request": { "$ref": "CheckCompatibilityRequest" }, "id": "analyticsdata.properties.checkCompatibility", "path": "v1beta/{+property}:checkCompatibility", "parameters": { "property": { "pattern": "^properties/[^/]+$", "description": "A Google Analytics GA4 property identifier whose events are tracked. To learn more, see [where to find your Property ID](https://developers.google.com/analytics/devguides/reporting/data/v1/property-id). `property` should be the same value as in your `runReport` request. Example: properties/1234 Set the Property ID to 0 for compatibility checking on dimensions and metrics common to all properties. In this special mode, this method will not return custom dimensions and metrics.", "type": "string", "required": true, "location": "path" } } }, "batchRunReports": { "description": "Returns multiple reports in a batch. All reports must be for the same GA4 Property.", "response": { "$ref": "BatchRunReportsResponse" }, "flatPath": "v1beta/properties/{propertiesId}:batchRunReports", "parameters": { "property": { "description": "A Google Analytics GA4 property identifier whose events are tracked. Specified in the URL path and not the body. To learn more, see [where to find your Property ID](https://developers.google.com/analytics/devguides/reporting/data/v1/property-id). This property must be specified for the batch. The property within RunReportRequest may either be unspecified or consistent with this property. Example: properties/1234", "required": true, "pattern": "^properties/[^/]+$", "location": "path", "type": "string" } }, "request": { "$ref": "BatchRunReportsRequest" }, "path": "v1beta/{+property}:batchRunReports", "httpMethod": "POST", "id": "analyticsdata.properties.batchRunReports", "parameterOrder": [ "property" ], "scopes": [ "https://www.googleapis.com/auth/analytics", "https://www.googleapis.com/auth/analytics.readonly" ] }, "runPivotReport": { "parameterOrder": [ "property" ], "path": "v1beta/{+property}:runPivotReport", "flatPath": "v1beta/properties/{propertiesId}:runPivotReport", "httpMethod": "POST", "request": { "$ref": "RunPivotReportRequest" }, "id": "analyticsdata.properties.runPivotReport", "parameters": { "property": { "type": "string", "location": "path", "required": true, "description": "A Google Analytics GA4 property identifier whose events are tracked. Specified in the URL path and not the body. To learn more, see [where to find your Property ID](https://developers.google.com/analytics/devguides/reporting/data/v1/property-id). Within a batch request, this property should either be unspecified or consistent with the batch-level property. Example: properties/1234", "pattern": "^properties/[^/]+$" } }, "description": "Returns a customized pivot report of your Google Analytics event data. Pivot reports are more advanced and expressive formats than regular reports. In a pivot report, dimensions are only visible if they are included in a pivot. Multiple pivots can be specified to further dissect your data.", "response": { "$ref": "RunPivotReportResponse" }, "scopes": [ "https://www.googleapis.com/auth/analytics", "https://www.googleapis.com/auth/analytics.readonly" ] }, "batchRunPivotReports": { "parameterOrder": [ "property" ], "description": "Returns multiple pivot reports in a batch. All reports must be for the same GA4 Property.", "scopes": [ "https://www.googleapis.com/auth/analytics", "https://www.googleapis.com/auth/analytics.readonly" ], "id": "analyticsdata.properties.batchRunPivotReports", "path": "v1beta/{+property}:batchRunPivotReports", "response": { "$ref": "BatchRunPivotReportsResponse" }, "httpMethod": "POST", "flatPath": "v1beta/properties/{propertiesId}:batchRunPivotReports", "request": { "$ref": "BatchRunPivotReportsRequest" }, "parameters": { "property": { "pattern": "^properties/[^/]+$", "description": "A Google Analytics GA4 property identifier whose events are tracked. Specified in the URL path and not the body. To learn more, see [where to find your Property ID](https://developers.google.com/analytics/devguides/reporting/data/v1/property-id). This property must be specified for the batch. The property within RunPivotReportRequest may either be unspecified or consistent with this property. Example: properties/1234", "location": "path", "type": "string", "required": true } } }, "runReport": { "response": { "$ref": "RunReportResponse" }, "id": "analyticsdata.properties.runReport", "flatPath": "v1beta/properties/{propertiesId}:runReport", "description": "Returns a customized report of your Google Analytics event data. Reports contain statistics derived from data collected by the Google Analytics tracking code. The data returned from the API is as a table with columns for the requested dimensions and metrics. Metrics are individual measurements of user activity on your property, such as active users or event count. Dimensions break down metrics across some common criteria, such as country or event name. For a guide to constructing requests & understanding responses, see [Creating a Report](https://developers.google.com/analytics/devguides/reporting/data/v1/basics).", "path": "v1beta/{+property}:runReport", "request": { "$ref": "RunReportRequest" }, "parameterOrder": [ "property" ], "parameters": { "property": { "description": "A Google Analytics GA4 property identifier whose events are tracked. Specified in the URL path and not the body. To learn more, see [where to find your Property ID](https://developers.google.com/analytics/devguides/reporting/data/v1/property-id). Within a batch request, this property should either be unspecified or consistent with the batch-level property. Example: properties/1234", "type": "string", "location": "path", "required": true, "pattern": "^properties/[^/]+$" } }, "httpMethod": "POST", "scopes": [ "https://www.googleapis.com/auth/analytics", "https://www.googleapis.com/auth/analytics.readonly" ] } } } }, "rootUrl": "https://analyticsdata.googleapis.com/", "version_module": true, "auth": { "oauth2": { "scopes": { "https://www.googleapis.com/auth/analytics": { "description": "View and manage your Google Analytics data" }, "https://www.googleapis.com/auth/analytics.readonly": { "description": "See and download your Google Analytics data" } } } }, "revision": "20220711", "batchPath": "batch", "baseUrl": "https://analyticsdata.googleapis.com/", "protocol": "rest", "kind": "discovery#restDescription", "mtlsRootUrl": "https://analyticsdata.mtls.googleapis.com/", "ownerDomain": "google.com", "ownerName": "Google", "parameters": { "$.xgafv": { "location": "query", "enumDescriptions": [ "v1 error format", "v2 error format" ], "enum": [ "1", "2" ], "type": "string", "description": "V1 error format." }, "upload_protocol": { "location": "query", "type": "string", "description": "Upload protocol for media (e.g. \"raw\", \"multipart\")." }, "quotaUser": { "location": "query", "description": "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.", "type": "string" }, "access_token": { "type": "string", "location": "query", "description": "OAuth access token." }, "key": { "location": "query", "type": "string", "description": "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token." }, "fields": { "location": "query", "description": "Selector specifying which fields to include in a partial response.", "type": "string" }, "alt": { "description": "Data format for response.", "type": "string", "default": "json", "enumDescriptions": [ "Responses with Content-Type of application/json", "Media download with context-dependent Content-Type", "Responses with Content-Type of application/x-protobuf" ], "enum": [ "json", "media", "proto" ], "location": "query" }, "uploadType": { "type": "string", "location": "query", "description": "Legacy upload protocol for media (e.g. \"media\", \"multipart\")." }, "oauth_token": { "description": "OAuth 2.0 token for the current user.", "location": "query", "type": "string" }, "callback": { "type": "string", "description": "JSONP", "location": "query" }, "prettyPrint": { "description": "Returns response with indentations and line breaks.", "default": "true", "type": "boolean", "location": "query" } }, "fullyEncodeReservedExpansion": true, "version": "v1beta", "id": "analyticsdata:v1beta", "documentationLink": "https://developers.google.com/analytics/devguides/reporting/data/v1/", "title": "Google Analytics Data API", "canonicalName": "AnalyticsData" }
]===]))
