local decode = require("cjson").new().decode
return assert(decode([===[
{ "schemas": { "GoogleCloudBillingBudgetsV1beta1Filter": { "properties": { "creditTypes": { "type": "array", "items": { "type": "string" }, "description": "Optional. If Filter.credit_types_treatment is INCLUDE_SPECIFIED_CREDITS, this is a list of credit types to be subtracted from gross cost to determine the spend for threshold calculations. See [a list of acceptable credit type values](https://cloud.google.com/billing/docs/how-to/export-data-bigquery-tables#credits-type). If Filter.credit_types_treatment is **not** INCLUDE_SPECIFIED_CREDITS, this field must be empty." }, "projects": { "description": "Optional. A set of projects of the form `projects/{project}`, specifying that usage from only this set of projects should be included in the budget. If omitted, the report will include all usage for the billing account, regardless of which project the usage occurred on. Only zero or one project can be specified currently.", "items": { "type": "string" }, "type": "array" }, "services": { "items": { "type": "string" }, "type": "array", "description": "Optional. A set of services of the form `services/{service_id}`, specifying that usage from only this set of services should be included in the budget. If omitted, the report will include usage for all the services. The service names are available through the Catalog API: https://cloud.google.com/billing/v1/how-tos/catalog-api." }, "subaccounts": { "description": "Optional. A set of subaccounts of the form `billingAccounts/{account_id}`, specifying that usage from only this set of subaccounts should be included in the budget. If a subaccount is set to the name of the parent account, usage from the parent account will be included. If omitted, the report will include usage from the parent account and all subaccounts, if they exist.", "type": "array", "items": { "type": "string" } }, "creditTypesTreatment": { "description": "Optional. If not set, default behavior is `INCLUDE_ALL_CREDITS`.", "type": "string", "enum": [ "CREDIT_TYPES_TREATMENT_UNSPECIFIED", "INCLUDE_ALL_CREDITS", "EXCLUDE_ALL_CREDITS", "INCLUDE_SPECIFIED_CREDITS" ], "enumDescriptions": [ "", "All types of credit are subtracted from the gross cost to determine the spend for threshold calculations.", "All types of credit are added to the net cost to determine the spend for threshold calculations.", "[Credit types](https://cloud.google.com/billing/docs/how-to/export-data-bigquery-tables#credits-type) specified in the credit_types field are subtracted from the gross cost to determine the spend for threshold calculations." ] }, "customPeriod": { "$ref": "GoogleCloudBillingBudgetsV1beta1CustomPeriod", "description": "Optional. Specifies to track usage from any start date (required) to any end date (optional). This time period is static, it does not recur." }, "labels": { "description": "Optional. A single label and value pair specifying that usage from only this set of labeled resources should be included in the budget. If omitted, the report will include all labeled and unlabeled usage. An object containing a single `\"key\": value` pair. Example: `{ \"name\": \"wrench\" }`. _Currently, multiple entries or multiple values per entry are not allowed._", "additionalProperties": { "type": "array", "items": { "type": "any" } }, "type": "object" }, "calendarPeriod": { "description": "Optional. Specifies to track usage for recurring calendar period. For example, assume that CalendarPeriod.QUARTER is set. The budget will track usage from April 1 to June 30, when the current calendar month is April, May, June. After that, it will track usage from July 1 to September 30 when the current calendar month is July, August, September, so on.", "type": "string", "enum": [ "CALENDAR_PERIOD_UNSPECIFIED", "MONTH", "QUARTER", "YEAR" ], "enumDescriptions": [ "Calendar period is unset. This is the default if the budget is for a custom time period (CustomPeriod).", "A month. Month starts on the first day of each month, such as January 1, February 1, March 1, and so on.", "A quarter. Quarters start on dates January 1, April 1, July 1, and October 1 of each year.", "A year. Year starts on January 1." ] } }, "description": "A filter for a budget, limiting the scope of the cost to calculate.", "type": "object", "id": "GoogleCloudBillingBudgetsV1beta1Filter" }, "GoogleCloudBillingBudgetsV1beta1Budget": { "id": "GoogleCloudBillingBudgetsV1beta1Budget", "description": "A budget is a plan that describes what you expect to spend on Cloud projects, plus the rules to execute as spend is tracked against that plan, (for example, send an alert when 90% of the target spend is met). The budget time period is configurable, with options such as month (default), quarter, year, or custom time period.", "type": "object", "properties": { "amount": { "description": "Required. Budgeted amount.", "$ref": "GoogleCloudBillingBudgetsV1beta1BudgetAmount" }, "allUpdatesRule": { "description": "Optional. Rules to apply to notifications sent based on budget spend and thresholds.", "$ref": "GoogleCloudBillingBudgetsV1beta1AllUpdatesRule" }, "name": { "readOnly": true, "description": "Output only. Resource name of the budget. The resource name implies the scope of a budget. Values are of the form `billingAccounts/{billingAccountId}/budgets/{budgetId}`.", "type": "string" }, "etag": { "description": "Optional. Etag to validate that the object is unchanged for a read-modify-write operation. An empty etag will cause an update to overwrite other changes.", "type": "string" }, "thresholdRules": { "type": "array", "items": { "$ref": "GoogleCloudBillingBudgetsV1beta1ThresholdRule" }, "description": "Optional. Rules that trigger alerts (notifications of thresholds being crossed) when spend exceeds the specified percentages of the budget. Optional for `pubsubTopic` notifications. Required if using email notifications." }, "displayName": { "description": "User data for display name in UI. Validation: \u003c= 60 chars.", "type": "string" }, "budgetFilter": { "description": "Optional. Filters that define which resources are used to compute the actual spend against the budget amount, such as projects, services, and the budget's time period, as well as other filters.", "$ref": "GoogleCloudBillingBudgetsV1beta1Filter" } } }, "GoogleCloudBillingBudgetsV1beta1LastPeriodAmount": { "description": "Describes a budget amount targeted to the last Filter.calendar_period spend. At this time, the amount is automatically 100% of the last calendar period's spend; that is, there are no other options yet. Future configuration options will be described here (for example, configuring a percentage of last period's spend). LastPeriodAmount cannot be set for a budget configured with a Filter.custom_period.", "properties": {}, "type": "object", "id": "GoogleCloudBillingBudgetsV1beta1LastPeriodAmount" }, "GoogleCloudBillingBudgetsV1beta1ListBudgetsResponse": { "description": "Response for ListBudgets", "id": "GoogleCloudBillingBudgetsV1beta1ListBudgetsResponse", "type": "object", "properties": { "budgets": { "description": "List of the budgets owned by the requested billing account.", "type": "array", "items": { "$ref": "GoogleCloudBillingBudgetsV1beta1Budget" } }, "nextPageToken": { "description": "If not empty, indicates that there may be more budgets that match the request; this value should be passed in a new `ListBudgetsRequest`.", "type": "string" } } }, "GoogleCloudBillingBudgetsV1beta1UpdateBudgetRequest": { "description": "Request for UpdateBudget", "type": "object", "id": "GoogleCloudBillingBudgetsV1beta1UpdateBudgetRequest", "properties": { "budget": { "description": "Required. The updated budget object. The budget to update is specified by the budget name in the budget.", "$ref": "GoogleCloudBillingBudgetsV1beta1Budget" }, "updateMask": { "format": "google-fieldmask", "type": "string", "description": "Optional. Indicates which fields in the provided budget to update. Read-only fields (such as `name`) cannot be changed. If this is not provided, then only fields with non-default values from the request are updated. See https://developers.google.com/protocol-buffers/docs/proto3#default for more details about default values." } } }, "GoogleCloudBillingBudgetsV1beta1ThresholdRule": { "type": "object", "properties": { "spendBasis": { "type": "string", "enumDescriptions": [ "Unspecified threshold basis.", "Use current spend as the basis for comparison against the threshold.", "Use forecasted spend for the period as the basis for comparison against the threshold. FORECASTED_SPEND can only be set when the budget's time period is a Filter.calendar_period. It cannot be set in combination with Filter.custom_period." ], "enum": [ "BASIS_UNSPECIFIED", "CURRENT_SPEND", "FORECASTED_SPEND" ], "description": "Optional. The type of basis used to determine if spend has passed the threshold. Behavior defaults to CURRENT_SPEND if not set." }, "thresholdPercent": { "format": "double", "description": "Required. Send an alert when this threshold is exceeded. This is a 1.0-based percentage, so 0.5 = 50%. Validation: non-negative number.", "type": "number" } }, "description": "ThresholdRule contains the definition of a threshold. Threshold rules define the triggering events used to generate a budget notification email. When a threshold is crossed (spend exceeds the specified percentages of the budget), budget alert emails are sent to the email recipients you specify in the [NotificationsRule](#notificationsrule). Threshold rules also affect the fields included in the [JSON data object](https://cloud.google.com/billing/docs/how-to/budgets-programmatic-notifications#notification_format) sent to a Pub/Sub topic. Threshold rules are _required_ if using email notifications. Threshold rules are _optional_ if only setting a [`pubsubTopic` NotificationsRule](#NotificationsRule), unless you want your JSON data object to include data about the thresholds you set. For more information, see [set budget threshold rules and actions](https://cloud.google.com/billing/docs/how-to/budgets#budget-actions).", "id": "GoogleCloudBillingBudgetsV1beta1ThresholdRule" }, "GoogleTypeMoney": { "id": "GoogleTypeMoney", "properties": { "units": { "description": "The whole units of the amount. For example if `currencyCode` is `\"USD\"`, then 1 unit is one US dollar.", "type": "string", "format": "int64" }, "currencyCode": { "description": "The three-letter currency code defined in ISO 4217.", "type": "string" }, "nanos": { "description": "Number of nano (10^-9) units of the amount. The value must be between -999,999,999 and +999,999,999 inclusive. If `units` is positive, `nanos` must be positive or zero. If `units` is zero, `nanos` can be positive, zero, or negative. If `units` is negative, `nanos` must be negative or zero. For example $-1.75 is represented as `units`=-1 and `nanos`=-750,000,000.", "type": "integer", "format": "int32" } }, "type": "object", "description": "Represents an amount of money with its currency type." }, "GoogleCloudBillingBudgetsV1beta1CustomPeriod": { "description": "All date times begin at 12 AM US and Canadian Pacific Time (UTC-8).", "id": "GoogleCloudBillingBudgetsV1beta1CustomPeriod", "properties": { "endDate": { "$ref": "GoogleTypeDate", "description": "Optional. The end date of the time period. Budgets with elapsed end date won't be processed. If unset, specifies to track all usage incurred since the start_date." }, "startDate": { "$ref": "GoogleTypeDate", "description": "Required. The start date must be after January 1, 2017." } }, "type": "object" }, "GoogleCloudBillingBudgetsV1beta1AllUpdatesRule": { "description": "AllUpdatesRule defines notifications that are sent based on budget spend and thresholds.", "id": "GoogleCloudBillingBudgetsV1beta1AllUpdatesRule", "properties": { "monitoringNotificationChannels": { "type": "array", "description": "Optional. Targets to send notifications to when a threshold is exceeded. This is in addition to default recipients who have billing account IAM roles. The value is the full REST resource name of a monitoring notification channel with the form `projects/{project_id}/notificationChannels/{channel_id}`. A maximum of 5 channels are allowed. See https://cloud.google.com/billing/docs/how-to/budgets-notification-recipients for more details.", "items": { "type": "string" } }, "pubsubTopic": { "description": "Optional. The name of the Pub/Sub topic where budget related messages will be published, in the form `projects/{project_id}/topics/{topic_id}`. Updates are sent at regular intervals to the topic. The topic needs to be created before the budget is created; see https://cloud.google.com/billing/docs/how-to/budgets-programmatic-notifications for more details. Caller is expected to have `pubsub.topics.setIamPolicy` permission on the topic when it's set for a budget, otherwise, the API call will fail with PERMISSION_DENIED. See https://cloud.google.com/billing/docs/how-to/budgets-programmatic-notifications#permissions_required_for_this_task for more details on Pub/Sub roles and permissions.", "type": "string" }, "disableDefaultIamRecipients": { "description": "Optional. When set to true, disables default notifications sent when a threshold is exceeded. Default notifications are sent to those with Billing Account Administrator and Billing Account User IAM roles for the target account.", "type": "boolean" }, "schemaVersion": { "type": "string", "description": "Optional. Required when AllUpdatesRule.pubsub_topic is set. The schema version of the notification sent to AllUpdatesRule.pubsub_topic. Only \"1.0\" is accepted. It represents the JSON schema as defined in https://cloud.google.com/billing/docs/how-to/budgets-programmatic-notifications#notification_format." } }, "type": "object" }, "GoogleCloudBillingBudgetsV1beta1BudgetAmount": { "properties": { "lastPeriodAmount": { "$ref": "GoogleCloudBillingBudgetsV1beta1LastPeriodAmount", "description": "Use the last period's actual spend as the budget for the present period. LastPeriodAmount can only be set when the budget's time period is a Filter.calendar_period. It cannot be set in combination with Filter.custom_period." }, "specifiedAmount": { "description": "A specified amount to use as the budget. `currency_code` is optional. If specified when creating a budget, it must match the currency of the billing account. If specified when updating a budget, it must match the currency_code of the existing budget. The `currency_code` is provided on output.", "$ref": "GoogleTypeMoney" } }, "description": "The budgeted amount for each usage period.", "type": "object", "id": "GoogleCloudBillingBudgetsV1beta1BudgetAmount" }, "GoogleTypeDate": { "properties": { "month": { "description": "Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.", "format": "int32", "type": "integer" }, "year": { "type": "integer", "format": "int32", "description": "Year of the date. Must be from 1 to 9999, or 0 to specify a date without a year." }, "day": { "description": "Day of a month. Must be from 1 to 31 and valid for the year and month, or 0 to specify a year by itself or a year and month where the day isn't significant.", "format": "int32", "type": "integer" } }, "id": "GoogleTypeDate", "description": "Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh A full date, with non-zero year, month, and day values. LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh A month and day, with a zero year (for example, an anniversary). LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh A year on its own, with a zero month and a zero day. LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh A year and month, with a zero day (for example, a credit card expiration date). Related types: LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh google.type.TimeOfDay LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh google.type.DateTime LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh google.protobuf.Timestamp", "type": "object" }, "GoogleProtobufEmpty": { "id": "GoogleProtobufEmpty", "type": "object", "description": "A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance: service Foo { rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty); }", "properties": {} }, "GoogleCloudBillingBudgetsV1beta1CreateBudgetRequest": { "description": "Request for CreateBudget", "properties": { "budget": { "$ref": "GoogleCloudBillingBudgetsV1beta1Budget", "description": "Required. Budget to create." } }, "type": "object", "id": "GoogleCloudBillingBudgetsV1beta1CreateBudgetRequest" } }, "ownerName": "Google", "title": "Cloud Billing Budget API", "ownerDomain": "google.com", "batchPath": "batch", "revision": "20220703", "name": "billingbudgets", "auth": { "oauth2": { "scopes": { "https://www.googleapis.com/auth/cloud-platform": { "description": "See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account." }, "https://www.googleapis.com/auth/cloud-billing": { "description": "View and manage your Google Cloud Platform billing accounts" } } } }, "servicePath": "", "description": "The Cloud Billing Budget API stores Cloud Billing budgets, which define a budget plan and the rules to execute as spend is tracked against that plan.", "version_module": true, "discoveryVersion": "v1", "baseUrl": "https://billingbudgets.googleapis.com/", "version": "v1beta1", "protocol": "rest", "canonicalName": "CloudBillingBudget", "documentationLink": "https://cloud.google.com/billing/docs/how-to/budget-api-overview", "id": "billingbudgets:v1beta1", "parameters": { "uploadType": { "description": "Legacy upload protocol for media (e.g. \"media\", \"multipart\").", "type": "string", "location": "query" }, "fields": { "description": "Selector specifying which fields to include in a partial response.", "type": "string", "location": "query" }, "alt": { "enum": [ "json", "media", "proto" ], "description": "Data format for response.", "enumDescriptions": [ "Responses with Content-Type of application/json", "Media download with context-dependent Content-Type", "Responses with Content-Type of application/x-protobuf" ], "default": "json", "location": "query", "type": "string" }, "access_token": { "description": "OAuth access token.", "location": "query", "type": "string" }, "$.xgafv": { "location": "query", "enumDescriptions": [ "v1 error format", "v2 error format" ], "description": "V1 error format.", "type": "string", "enum": [ "1", "2" ] }, "quotaUser": { "location": "query", "description": "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.", "type": "string" }, "upload_protocol": { "location": "query", "description": "Upload protocol for media (e.g. \"raw\", \"multipart\").", "type": "string" }, "key": { "description": "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.", "location": "query", "type": "string" }, "callback": { "description": "JSONP", "location": "query", "type": "string" }, "oauth_token": { "type": "string", "description": "OAuth 2.0 token for the current user.", "location": "query" }, "prettyPrint": { "description": "Returns response with indentations and line breaks.", "default": "true", "type": "boolean", "location": "query" } }, "resources": { "billingAccounts": { "resources": { "budgets": { "methods": { "get": { "httpMethod": "GET", "response": { "$ref": "GoogleCloudBillingBudgetsV1beta1Budget" }, "id": "billingbudgets.billingAccounts.budgets.get", "description": "Returns a budget. WARNING: There are some fields exposed on the Google Cloud Console that aren't available on this API. When reading from the API, you will not see these fields in the return value, though they may have been set in the Cloud Console.", "parameterOrder": [ "name" ], "parameters": { "name": { "type": "string", "location": "path", "description": "Required. Name of budget to get. Values are of the form `billingAccounts/{billingAccountId}/budgets/{budgetId}`.", "pattern": "^billingAccounts/[^/]+/budgets/[^/]+$", "required": true } }, "scopes": [ "https://www.googleapis.com/auth/cloud-billing", "https://www.googleapis.com/auth/cloud-platform" ], "flatPath": "v1beta1/billingAccounts/{billingAccountsId}/budgets/{budgetsId}", "path": "v1beta1/{+name}" }, "create": { "request": { "$ref": "GoogleCloudBillingBudgetsV1beta1CreateBudgetRequest" }, "id": "billingbudgets.billingAccounts.budgets.create", "description": "Creates a new budget. See [Quotas and limits](https://cloud.google.com/billing/quotas) for more information on the limits of the number of budgets you can create.", "httpMethod": "POST", "path": "v1beta1/{+parent}/budgets", "scopes": [ "https://www.googleapis.com/auth/cloud-billing", "https://www.googleapis.com/auth/cloud-platform" ], "response": { "$ref": "GoogleCloudBillingBudgetsV1beta1Budget" }, "parameters": { "parent": { "required": true, "pattern": "^billingAccounts/[^/]+$", "location": "path", "description": "Required. The name of the billing account to create the budget in. Values are of the form `billingAccounts/{billingAccountId}`.", "type": "string" } }, "parameterOrder": [ "parent" ], "flatPath": "v1beta1/billingAccounts/{billingAccountsId}/budgets" }, "delete": { "httpMethod": "DELETE", "scopes": [ "https://www.googleapis.com/auth/cloud-billing", "https://www.googleapis.com/auth/cloud-platform" ], "path": "v1beta1/{+name}", "id": "billingbudgets.billingAccounts.budgets.delete", "parameters": { "name": { "description": "Required. Name of the budget to delete. Values are of the form `billingAccounts/{billingAccountId}/budgets/{budgetId}`.", "pattern": "^billingAccounts/[^/]+/budgets/[^/]+$", "type": "string", "location": "path", "required": true } }, "response": { "$ref": "GoogleProtobufEmpty" }, "description": "Deletes a budget. Returns successfully if already deleted.", "flatPath": "v1beta1/billingAccounts/{billingAccountsId}/budgets/{budgetsId}", "parameterOrder": [ "name" ] }, "list": { "id": "billingbudgets.billingAccounts.budgets.list", "path": "v1beta1/{+parent}/budgets", "response": { "$ref": "GoogleCloudBillingBudgetsV1beta1ListBudgetsResponse" }, "description": "Returns a list of budgets for a billing account. WARNING: There are some fields exposed on the Google Cloud Console that aren't available on this API. When reading from the API, you will not see these fields in the return value, though they may have been set in the Cloud Console.", "httpMethod": "GET", "scopes": [ "https://www.googleapis.com/auth/cloud-billing", "https://www.googleapis.com/auth/cloud-platform" ], "parameters": { "pageSize": { "format": "int32", "description": "Optional. The maximum number of budgets to return per page. The default and maximum value are 100.", "location": "query", "type": "integer" }, "pageToken": { "type": "string", "location": "query", "description": "Optional. The value returned by the last `ListBudgetsResponse` which indicates that this is a continuation of a prior `ListBudgets` call, and that the system should return the next page of data." }, "parent": { "required": true, "pattern": "^billingAccounts/[^/]+$", "location": "path", "type": "string", "description": "Required. Name of billing account to list budgets under. Values are of the form `billingAccounts/{billingAccountId}`." } }, "parameterOrder": [ "parent" ], "flatPath": "v1beta1/billingAccounts/{billingAccountsId}/budgets" }, "patch": { "scopes": [ "https://www.googleapis.com/auth/cloud-billing", "https://www.googleapis.com/auth/cloud-platform" ], "description": "Updates a budget and returns the updated budget. WARNING: There are some fields exposed on the Google Cloud Console that aren't available on this API. Budget fields that are not exposed in this API will not be changed by this method.", "id": "billingbudgets.billingAccounts.budgets.patch", "parameters": { "name": { "type": "string", "pattern": "^billingAccounts/[^/]+/budgets/[^/]+$", "required": true, "location": "path", "description": "Output only. Resource name of the budget. The resource name implies the scope of a budget. Values are of the form `billingAccounts/{billingAccountId}/budgets/{budgetId}`." } }, "httpMethod": "PATCH", "path": "v1beta1/{+name}", "flatPath": "v1beta1/billingAccounts/{billingAccountsId}/budgets/{budgetsId}", "request": { "$ref": "GoogleCloudBillingBudgetsV1beta1UpdateBudgetRequest" }, "parameterOrder": [ "name" ], "response": { "$ref": "GoogleCloudBillingBudgetsV1beta1Budget" } } } } } } }, "kind": "discovery#restDescription", "rootUrl": "https://billingbudgets.googleapis.com/", "icons": { "x16": "http://www.google.com/images/icons/product/search-16.gif", "x32": "http://www.google.com/images/icons/product/search-32.gif" }, "basePath": "", "mtlsRootUrl": "https://billingbudgets.mtls.googleapis.com/", "fullyEncodeReservedExpansion": true }
]===]))
