local decode = require("cjson").new().decode
return assert(decode([===[
{ "canonicalName": "Cloud Profiler", "description": "Manages continuous profiling information.", "kind": "discovery#restDescription", "id": "cloudprofiler:v2", "discoveryVersion": "v1", "basePath": "", "fullyEncodeReservedExpansion": true, "schemas": { "Profile": { "type": "object", "id": "Profile", "description": "Profile resource.", "properties": { "labels": { "additionalProperties": { "type": "string" }, "description": "Input only. Labels associated to this specific profile. These labels will get merged with the deployment labels for the final data set. See documentation on deployment labels for validation rules and limits.", "type": "object" }, "name": { "description": "Output only. Opaque, server-assigned, unique ID for this profile.", "readOnly": true, "type": "string" }, "profileType": { "type": "string", "enum": [ "PROFILE_TYPE_UNSPECIFIED", "CPU", "WALL", "HEAP", "THREADS", "CONTENTION", "PEAK_HEAP", "HEAP_ALLOC" ], "enumDescriptions": [ "Unspecified profile type.", "Thread CPU time sampling.", "Wallclock time sampling. More expensive as stops all threads.", "In-use heap profile. Represents a snapshot of the allocations that are live at the time of the profiling.", "Single-shot collection of all thread stacks.", "Synchronization contention profile.", "Peak heap profile.", "Heap allocation profile. It represents the aggregation of all allocations made over the duration of the profile. All allocations are included, including those that might have been freed by the end of the profiling interval. The profile is in particular useful for garbage collecting languages to understand which parts of the code create most of the garbage collection pressure to see if those can be optimized." ], "description": "Type of profile. For offline mode, this must be specified when creating the profile. For online mode it is assigned and returned by the server." }, "duration": { "description": "Duration of the profiling session. Input (for the offline mode) or output (for the online mode). The field represents requested profiling duration. It may slightly differ from the effective profiling duration, which is recorded in the profile data, in case the profiling can't be stopped immediately (e.g. in case stopping the profiling is handled asynchronously).", "format": "google-duration", "type": "string" }, "profileBytes": { "type": "string", "format": "byte", "description": "Input only. Profile bytes, as a gzip compressed serialized proto, the format is https://github.com/google/pprof/blob/master/proto/profile.proto." }, "deployment": { "$ref": "Deployment", "description": "Deployment this profile corresponds to." } } }, "Deployment": { "properties": { "labels": { "additionalProperties": { "type": "string" }, "description": "Labels identify the deployment within the user universe and same target. Validation regex for label names: `^[a-z0-9]([a-z0-9-]{0,61}[a-z0-9])?$`. Value for an individual label must be \u003c= 512 bytes, the total size of all label names and values must be \u003c= 1024 bytes. Label named \"language\" can be used to record the programming language of the profiled deployment. The standard choices for the value include \"java\", \"go\", \"python\", \"ruby\", \"nodejs\", \"php\", \"dotnet\". For deployments running on Google Cloud Platform, \"zone\" or \"region\" label should be present describing the deployment location. An example of a zone is \"us-central1-a\", an example of a region is \"us-central1\" or \"us-central\".", "type": "object" }, "projectId": { "type": "string", "description": "Project ID is the ID of a cloud project. Validation regex: `^a-z{4,61}[a-z0-9]$`." }, "target": { "description": "Target is the service name used to group related deployments: LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh Service name for App Engine Flex / Standard. LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh Cluster and container name for GKE. LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh User-specified string for direct Compute Engine profiling (e.g. Java). LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh Job name for Dataflow. Validation regex: `^[a-z0-9]([-a-z0-9_.]{0,253}[a-z0-9])?$`.", "type": "string" } }, "description": "Deployment contains the deployment identification information.", "id": "Deployment", "type": "object" }, "CreateProfileRequest": { "type": "object", "description": "CreateProfileRequest describes a profile resource online creation request. The deployment field must be populated. The profile_type specifies the list of profile types supported by the agent. The creation call will hang until a profile of one of these types needs to be collected. ", "id": "CreateProfileRequest", "properties": { "profileType": { "description": "Required. One or more profile types that the agent is capable of providing.", "items": { "enumDescriptions": [ "Unspecified profile type.", "Thread CPU time sampling.", "Wallclock time sampling. More expensive as stops all threads.", "In-use heap profile. Represents a snapshot of the allocations that are live at the time of the profiling.", "Single-shot collection of all thread stacks.", "Synchronization contention profile.", "Peak heap profile.", "Heap allocation profile. It represents the aggregation of all allocations made over the duration of the profile. All allocations are included, including those that might have been freed by the end of the profiling interval. The profile is in particular useful for garbage collecting languages to understand which parts of the code create most of the garbage collection pressure to see if those can be optimized." ], "type": "string", "enum": [ "PROFILE_TYPE_UNSPECIFIED", "CPU", "WALL", "HEAP", "THREADS", "CONTENTION", "PEAK_HEAP", "HEAP_ALLOC" ] }, "type": "array" }, "deployment": { "description": "Required. Deployment details.", "$ref": "Deployment" } } } }, "version_module": true, "documentationLink": "https://cloud.google.com/profiler/", "auth": { "oauth2": { "scopes": { "https://www.googleapis.com/auth/monitoring.write": { "description": "Publish metric data to your Google Cloud projects" }, "https://www.googleapis.com/auth/cloud-platform": { "description": "See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account." }, "https://www.googleapis.com/auth/monitoring": { "description": "View and write monitoring data for all of your Google and third-party Cloud and API projects" } } } }, "protocol": "rest", "icons": { "x32": "http://www.google.com/images/icons/product/search-32.gif", "x16": "http://www.google.com/images/icons/product/search-16.gif" }, "rootUrl": "https://cloudprofiler.googleapis.com/", "mtlsRootUrl": "https://cloudprofiler.mtls.googleapis.com/", "ownerDomain": "google.com", "batchPath": "batch", "name": "cloudprofiler", "revision": "20220708", "baseUrl": "https://cloudprofiler.googleapis.com/", "version": "v2", "resources": { "projects": { "resources": { "profiles": { "methods": { "create": { "scopes": [ "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/monitoring", "https://www.googleapis.com/auth/monitoring.write" ], "request": { "$ref": "CreateProfileRequest" }, "parameterOrder": [ "parent" ], "response": { "$ref": "Profile" }, "flatPath": "v2/projects/{projectsId}/profiles", "description": "CreateProfile creates a new profile resource in the online mode. The server ensures that the new profiles are created at a constant rate per deployment, so the creation request may hang for some time until the next profile session is available. The request may fail with ABORTED error if the creation is not available within ~1m, the response will indicate the duration of the backoff the client should take before attempting creating a profile again. The backoff duration is returned in google.rpc.RetryInfo extension on the response status. To a gRPC client, the extension will be return as a binary-serialized proto in the trailing metadata item named \"google.rpc.retryinfo-bin\". ", "id": "cloudprofiler.projects.profiles.create", "path": "v2/{+parent}/profiles", "httpMethod": "POST", "parameters": { "parent": { "required": true, "pattern": "^projects/[^/]+$", "description": "Parent project to create the profile in.", "location": "path", "type": "string" } } }, "patch": { "parameters": { "name": { "description": "Output only. Opaque, server-assigned, unique ID for this profile.", "type": "string", "pattern": "^projects/[^/]+/profiles/[^/]+$", "required": true, "location": "path" }, "updateMask": { "location": "query", "format": "google-fieldmask", "description": "Field mask used to specify the fields to be overwritten. Currently only profile_bytes and labels fields are supported by UpdateProfile, so only those fields can be specified in the mask. When no mask is provided, all fields are overwritten.", "type": "string" } }, "flatPath": "v2/projects/{projectsId}/profiles/{profilesId}", "id": "cloudprofiler.projects.profiles.patch", "httpMethod": "PATCH", "description": "UpdateProfile updates the profile bytes and labels on the profile resource created in the online mode. Updating the bytes for profiles created in the offline mode is currently not supported: the profile content must be provided at the time of the profile creation.", "scopes": [ "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/monitoring", "https://www.googleapis.com/auth/monitoring.write" ], "parameterOrder": [ "name" ], "path": "v2/{+name}", "request": { "$ref": "Profile" }, "response": { "$ref": "Profile" } }, "createOffline": { "parameterOrder": [ "parent" ], "scopes": [ "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/monitoring", "https://www.googleapis.com/auth/monitoring.write" ], "flatPath": "v2/projects/{projectsId}/profiles:createOffline", "response": { "$ref": "Profile" }, "id": "cloudprofiler.projects.profiles.createOffline", "httpMethod": "POST", "parameters": { "parent": { "location": "path", "description": "Parent project to create the profile in.", "pattern": "^projects/[^/]+$", "type": "string", "required": true } }, "path": "v2/{+parent}/profiles:createOffline", "description": "CreateOfflineProfile creates a new profile resource in the offline mode. The client provides the profile to create along with the profile bytes, the server records it.", "request": { "$ref": "Profile" } } } } } } }, "servicePath": "", "ownerName": "Google", "parameters": { "oauth_token": { "location": "query", "description": "OAuth 2.0 token for the current user.", "type": "string" }, "quotaUser": { "description": "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.", "location": "query", "type": "string" }, "$.xgafv": { "enum": [ "1", "2" ], "description": "V1 error format.", "type": "string", "location": "query", "enumDescriptions": [ "v1 error format", "v2 error format" ] }, "callback": { "description": "JSONP", "location": "query", "type": "string" }, "alt": { "default": "json", "location": "query", "description": "Data format for response.", "enum": [ "json", "media", "proto" ], "type": "string", "enumDescriptions": [ "Responses with Content-Type of application/json", "Media download with context-dependent Content-Type", "Responses with Content-Type of application/x-protobuf" ] }, "access_token": { "type": "string", "description": "OAuth access token.", "location": "query" }, "uploadType": { "location": "query", "type": "string", "description": "Legacy upload protocol for media (e.g. \"media\", \"multipart\")." }, "fields": { "location": "query", "type": "string", "description": "Selector specifying which fields to include in a partial response." }, "key": { "type": "string", "description": "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.", "location": "query" }, "prettyPrint": { "type": "boolean", "default": "true", "location": "query", "description": "Returns response with indentations and line breaks." }, "upload_protocol": { "type": "string", "description": "Upload protocol for media (e.g. \"raw\", \"multipart\").", "location": "query" } }, "title": "Stackdriver Profiler API" }
]===]))
