local decode = require("cjson").new().decode
return assert(decode([===[
{ "ownerName": "Google", "protocol": "rest", "schemas": { "SetIamPolicyRequest": { "type": "object", "properties": { "policy": { "description": "REQUIRED: The complete policy to be applied to the `resource`. The size of the policy is limited to a few 10s of KB. An empty policy is a valid policy but certain Google Cloud services (such as Projects) might reject them.", "$ref": "Policy" } }, "description": "Request message for `SetIamPolicy` method.", "id": "SetIamPolicyRequest" }, "EndCondition": { "properties": { "cardinality": { "description": "The cardinality of the `EndCondition`.", "$ref": "Cardinality" } }, "type": "object", "description": "The condition that a Waiter resource is waiting for.", "id": "EndCondition" }, "Status": { "description": "The `Status` type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by [gRPC](https://github.com/grpc). Each `Status` message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the [API Design Guide](https://cloud.google.com/apis/design/errors).", "id": "Status", "type": "object", "properties": { "details": { "type": "array", "items": { "type": "object", "additionalProperties": { "type": "any", "description": "Properties of the object. Contains field @type with type URL." } }, "description": "A list of messages that carry the error details. There is a common set of message types for APIs to use." }, "code": { "format": "int32", "description": "The status code, which should be an enum value of google.rpc.Code.", "type": "integer" }, "message": { "type": "string", "description": "A developer-facing error message, which should be in English. Any user-facing error message should be localized and sent in the google.rpc.Status.details field, or localized by the client." } } }, "Waiter": { "description": "A Waiter resource waits for some end condition within a RuntimeConfig resource to be met before it returns. For example, assume you have a distributed system where each node writes to a Variable resource indicating the node's readiness as part of the startup process. You then configure a Waiter resource with the success condition set to wait until some number of nodes have checked in. Afterwards, your application runs some arbitrary code after the condition has been met and the waiter returns successfully. Once created, a Waiter resource is immutable. To learn more about using waiters, read the [Creating a Waiter](/deployment-manager/runtime-configurator/creating-a-waiter) documentation.", "properties": { "error": { "description": "Output only. If the waiter ended due to a failure or timeout, this value will be set.", "$ref": "Status" }, "name": { "type": "string", "description": "The name of the Waiter resource, in the format: projects/[PROJECT_ID]/configs/[CONFIG_NAME]/waiters/[WAITER_NAME] The `[PROJECT_ID]` must be a valid Google Cloud project ID, the `[CONFIG_NAME]` must be a valid RuntimeConfig resource, the `[WAITER_NAME]` must match RFC 1035 segment specification, and the length of `[WAITER_NAME]` must be less than 64 bytes. After you create a Waiter resource, you cannot change the resource name." }, "createTime": { "description": "Output only. The instant at which this Waiter resource was created. Adding the value of `timeout` to this instant yields the timeout deadline for the waiter.", "format": "google-datetime", "type": "string" }, "success": { "description": "[Required] The success condition. If this condition is met, `done` will be set to `true` and the `error` value will remain unset. The failure condition takes precedence over the success condition. If both conditions are met, a failure will be indicated.", "$ref": "EndCondition" }, "failure": { "description": "[Optional] The failure condition of this waiter. If this condition is met, `done` will be set to `true` and the `error` code will be set to `ABORTED`. The failure condition takes precedence over the success condition. If both conditions are met, a failure will be indicated. This value is optional; if no failure condition is set, the only failure scenario will be a timeout.", "$ref": "EndCondition" }, "timeout": { "description": "[Required] Specifies the timeout of the waiter in seconds, beginning from the instant that `waiters().create` method is called. If this time elapses before the success or failure conditions are met, the waiter fails and sets the `error` code to `DEADLINE_EXCEEDED`.", "type": "string", "format": "google-duration" }, "done": { "type": "boolean", "description": "Output only. If the value is `false`, it means the waiter is still waiting for one of its conditions to be met. If true, the waiter has finished. If the waiter finished due to a timeout or failure, `error` will be set." } }, "id": "Waiter", "type": "object" }, "ListConfigsResponse": { "type": "object", "properties": { "configs": { "description": "A list of the configurations in the project. The order of returned objects is arbitrary; that is, it is not ordered in any particular way.", "items": { "$ref": "RuntimeConfig" }, "type": "array" }, "nextPageToken": { "description": "This token allows you to get the next page of results for list requests. If the number of results is larger than `pageSize`, use the `nextPageToken` as a value for the query parameter `pageToken` in the next list request. Subsequent list requests will have their own `nextPageToken` to continue paging through the results", "type": "string" } }, "description": "`ListConfigs()` returns the following response. The order of returned objects is arbitrary; that is, it is not ordered in any particular way.", "id": "ListConfigsResponse" }, "Variable": { "id": "Variable", "properties": { "name": { "type": "string", "description": "The name of the variable resource, in the format: projects/[PROJECT_ID]/configs/[CONFIG_NAME]/variables/[VARIABLE_NAME] The `[PROJECT_ID]` must be a valid project ID, `[CONFIG_NAME]` must be a valid RuntimeConfig resource and `[VARIABLE_NAME]` follows Unix file system file path naming. The `[VARIABLE_NAME]` can contain ASCII letters, numbers, slashes and dashes. Slashes are used as path element separators and are not part of the `[VARIABLE_NAME]` itself, so `[VARIABLE_NAME]` must contain at least one non-slash character. Multiple slashes are coalesced into single slash character. Each path segment should match [0-9A-Za-z](?:[_.A-Za-z0-9-]{0,62}[_.A-Za-z0-9])? regular expression. The length of a `[VARIABLE_NAME]` must be less than 256 characters. Once you create a variable, you cannot change the variable name." }, "state": { "enumDescriptions": [ "Default variable state.", "The variable was updated, while `variables().watch` was executing.", "The variable was deleted, while `variables().watch` was executing." ], "enum": [ "VARIABLE_STATE_UNSPECIFIED", "UPDATED", "DELETED" ], "description": "Output only. The current state of the variable. The variable state indicates the outcome of the `variables().watch` call and is visible through the `get` and `list` calls.", "type": "string" }, "value": { "description": "The binary value of the variable. The length of the value must be less than 4096 bytes. Empty values are also accepted. The value must be base64 encoded, and must comply with IETF RFC4648 (https://www.ietf.org/rfc/rfc4648.txt). Only one of `value` or `text` can be set.", "type": "string", "format": "byte" }, "text": { "description": "The string value of the variable. The length of the value must be less than 4096 bytes. Empty values are also accepted. For example, `text: \"my text value\"`. The string must be valid UTF-8.", "type": "string" }, "updateTime": { "description": "Output only. The time of the last variable update. Timestamp will be UTC timestamp.", "type": "string", "format": "google-datetime" } }, "type": "object", "description": "Describes a single variable within a RuntimeConfig resource. The name denotes the hierarchical variable name. For example, `ports/serving_port` is a valid variable name. The variable value is an opaque string and only leaf variables can have values (that is, variables that do not have any child variables)." }, "TestIamPermissionsRequest": { "id": "TestIamPermissionsRequest", "type": "object", "description": "Request message for `TestIamPermissions` method.", "properties": { "permissions": { "type": "array", "items": { "type": "string" }, "description": "The set of permissions to check for the `resource`. Permissions with wildcards (such as `*` or `storage.*`) are not allowed. For more information see [IAM Overview](https://cloud.google.com/iam/docs/overview#permissions)." } } }, "Operation": { "properties": { "metadata": { "additionalProperties": { "type": "any", "description": "Properties of the object. Contains field @type with type URL." }, "type": "object", "description": "Service-specific metadata associated with the operation. It typically contains progress information and common metadata such as create time. Some services might not provide such metadata. Any method that returns a long-running operation should document the metadata type, if any." }, "error": { "description": "The error result of the operation in case of failure or cancellation.", "$ref": "Status" }, "name": { "type": "string", "description": "The server-assigned name, which is only unique within the same service that originally returns it. If you use the default HTTP mapping, the `name` should be a resource name ending with `operations/{unique_id}`." }, "done": { "type": "boolean", "description": "If the value is `false`, it means the operation is still in progress. If `true`, the operation is completed, and either `error` or `response` is available." }, "response": { "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "description": "The normal response of the operation in case of success. If the original method returns no data on success, such as `Delete`, the response is `google.protobuf.Empty`. If the original method is standard `Get`/`Create`/`Update`, the response should be the resource. For other methods, the response should have the type `XxxResponse`, where `Xxx` is the original method name. For example, if the original method name is `TakeSnapshot()`, the inferred response type is `TakeSnapshotResponse`.", "type": "object" } }, "description": "This resource represents a long-running operation that is the result of a network API call.", "id": "Operation", "type": "object" }, "Cardinality": { "id": "Cardinality", "properties": { "path": { "description": "The root of the variable subtree to monitor. For example, `/foo`.", "type": "string" }, "number": { "format": "int32", "type": "integer", "description": "The number variables under the `path` that must exist to meet this condition. Defaults to 1 if not specified." } }, "description": "A Cardinality condition for the Waiter resource. A cardinality condition is met when the number of variables under a specified path prefix reaches a predefined number. For example, if you set a Cardinality condition where the `path` is set to `/foo` and the number of paths is set to `2`, the following variables would meet the condition in a RuntimeConfig resource: + `/foo/variable1 = \"value1\"` + `/foo/variable2 = \"value2\"` + `/bar/variable3 = \"value3\"` It would not satisfy the same condition with the `number` set to `3`, however, because there is only 2 paths that start with `/foo`. Cardinality conditions are recursive; all subtrees under the specific path prefix are counted.", "type": "object" }, "Policy": { "properties": { "etag": { "description": "`etag` is used for optimistic concurrency control as a way to help prevent simultaneous updates of a policy from overwriting each other. It is strongly suggested that systems make use of the `etag` in the read-modify-write cycle to perform policy updates in order to avoid race conditions: An `etag` is returned in the response to `getIamPolicy`, and systems are expected to put that etag in the request to `setIamPolicy` to ensure that their change will be applied to the same version of the policy. **Important:** If you use IAM Conditions, you must include the `etag` field whenever you call `setIamPolicy`. If you omit this field, then IAM allows you to overwrite a version `3` policy with a version `1` policy, and all of the conditions in the version `3` policy are lost.", "type": "string", "format": "byte" }, "bindings": { "items": { "$ref": "Binding" }, "type": "array", "description": "Associates a list of `members`, or principals, with a `role`. Optionally, may specify a `condition` that determines how and when the `bindings` are applied. Each of the `bindings` must contain at least one principal. The `bindings` in a `Policy` can refer to up to 1,500 principals; up to 250 of these principals can be Google groups. Each occurrence of a principal counts towards these limits. For example, if the `bindings` grant 50 different roles to `user:alice@example.com`, and not to any other principal, then you can add another 1,450 principals to the `bindings` in the `Policy`." }, "version": { "type": "integer", "description": "Specifies the format of the policy. Valid values are `0`, `1`, and `3`. Requests that specify an invalid value are rejected. Any operation that affects conditional role bindings must specify version `3`. This requirement applies to the following operations: LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh Getting a policy that includes a conditional role binding LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh Adding a conditional role binding to a policy LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh Changing a conditional role binding in a policy LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh Removing any role binding, with or without a condition, from a policy that includes conditions **Important:** If you use IAM Conditions, you must include the `etag` field whenever you call `setIamPolicy`. If you omit this field, then IAM allows you to overwrite a version `3` policy with a version `1` policy, and all of the conditions in the version `3` policy are lost. If a policy does not include any conditions, operations on that policy may specify any valid version or leave the field unset. To learn which resources support conditions in their IAM policies, see the [IAM documentation](https://cloud.google.com/iam/help/conditions/resource-policies).", "format": "int32" } }, "id": "Policy", "type": "object", "description": "An Identity and Access Management (IAM) policy, which specifies access controls for Google Cloud resources. A `Policy` is a collection of `bindings`. A `binding` binds one or more `members`, or principals, to a single `role`. Principals can be user accounts, service accounts, Google groups, and domains (such as G Suite). A `role` is a named list of permissions; each `role` can be an IAM predefined role or a user-created custom role. For some types of Google Cloud resources, a `binding` can also specify a `condition`, which is a logical expression that allows access to a resource only if the expression evaluates to `true`. A condition can add constraints based on attributes of the request, the resource, or both. To learn which resources support conditions in their IAM policies, see the [IAM documentation](https://cloud.google.com/iam/help/conditions/resource-policies). **JSON example:** { \"bindings\": [ { \"role\": \"roles/resourcemanager.organizationAdmin\", \"members\": [ \"user:mike@example.com\", \"group:admins@example.com\", \"domain:google.com\", \"serviceAccount:my-project-id@appspot.gserviceaccount.com\" ] }, { \"role\": \"roles/resourcemanager.organizationViewer\", \"members\": [ \"user:eve@example.com\" ], \"condition\": { \"title\": \"expirable access\", \"description\": \"Does not grant access after Sep 2020\", \"expression\": \"request.time \u003c timestamp('2020-10-01T00:00:00.000Z')\", } } ], \"etag\": \"BwWWja0YfJA=\", \"version\": 3 } **YAML example:** bindings: - members: - user:mike@example.com - group:admins@example.com - domain:google.com - serviceAccount:my-project-id@appspot.gserviceaccount.com role: roles/resourcemanager.organizationAdmin - members: - user:eve@example.com role: roles/resourcemanager.organizationViewer condition: title: expirable access description: Does not grant access after Sep 2020 expression: request.time \u003c timestamp('2020-10-01T00:00:00.000Z') etag: BwWWja0YfJA= version: 3 For a description of IAM and its features, see the [IAM documentation](https://cloud.google.com/iam/docs/)." }, "Empty": { "type": "object", "id": "Empty", "properties": {}, "description": "A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance: service Foo { rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty); }" }, "Expr": { "id": "Expr", "properties": { "description": { "description": "Optional. Description of the expression. This is a longer text which describes the expression, e.g. when hovered over it in a UI.", "type": "string" }, "expression": { "type": "string", "description": "Textual representation of an expression in Common Expression Language syntax." }, "title": { "type": "string", "description": "Optional. Title for the expression, i.e. a short string describing its purpose. This can be used e.g. in UIs which allow to enter the expression." }, "location": { "type": "string", "description": "Optional. String indicating the location of the expression for error reporting, e.g. a file name and a position in the file." } }, "type": "object", "description": "Represents a textual expression in the Common Expression Language (CEL) syntax. CEL is a C-like expression language. The syntax and semantics of CEL are documented at https://github.com/google/cel-spec. Example (Comparison): title: \"Summary size limit\" description: \"Determines if a summary is less than 100 chars\" expression: \"document.summary.size() \u003c 100\" Example (Equality): title: \"Requestor is owner\" description: \"Determines if requestor is the document owner\" expression: \"document.owner == request.auth.claims.email\" Example (Logic): title: \"Public documents\" description: \"Determine whether the document should be publicly visible\" expression: \"document.type != 'private' && document.type != 'internal'\" Example (Data Manipulation): title: \"Notification string\" description: \"Create a notification string with a timestamp.\" expression: \"'New message received at ' + string(document.create_time)\" The exact variables and functions that may be referenced within an expression are determined by the service that evaluates it. See the service documentation for additional information." }, "TestIamPermissionsResponse": { "id": "TestIamPermissionsResponse", "description": "Response message for `TestIamPermissions` method.", "type": "object", "properties": { "permissions": { "type": "array", "items": { "type": "string" }, "description": "A subset of `TestPermissionsRequest.permissions` that the caller is allowed." } } }, "Binding": { "type": "object", "properties": { "role": { "type": "string", "description": "Role that is assigned to the list of `members`, or principals. For example, `roles/viewer`, `roles/editor`, or `roles/owner`." }, "members": { "items": { "type": "string" }, "description": "Specifies the principals requesting access for a Google Cloud resource. `members` can have the following values: LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh `allUsers`: A special identifier that represents anyone who is on the internet; with or without a Google account. LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh `allAuthenticatedUsers`: A special identifier that represents anyone who is authenticated with a Google account or a service account. LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh `user:{emailid}`: An email address that represents a specific Google account. For example, `alice@example.com` . LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh `serviceAccount:{emailid}`: An email address that represents a service account. For example, `my-other-app@appspot.gserviceaccount.com`. LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh `group:{emailid}`: An email address that represents a Google group. For example, `admins@example.com`. LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh `deleted:user:{emailid}?uid={uniqueid}`: An email address (plus unique identifier) representing a user that has been recently deleted. For example, `alice@example.com?uid=123456789012345678901`. If the user is recovered, this value reverts to `user:{emailid}` and the recovered user retains the role in the binding. LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh `deleted:serviceAccount:{emailid}?uid={uniqueid}`: An email address (plus unique identifier) representing a service account that has been recently deleted. For example, `my-other-app@appspot.gserviceaccount.com?uid=123456789012345678901`. If the service account is undeleted, this value reverts to `serviceAccount:{emailid}` and the undeleted service account retains the role in the binding. LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh `deleted:group:{emailid}?uid={uniqueid}`: An email address (plus unique identifier) representing a Google group that has been recently deleted. For example, `admins@example.com?uid=123456789012345678901`. If the group is recovered, this value reverts to `group:{emailid}` and the recovered group retains the role in the binding. LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh `domain:{domain}`: The G Suite domain (primary) that represents all the users of that domain. For example, `google.com` or `example.com`. ", "type": "array" }, "condition": { "$ref": "Expr", "description": "The condition that is associated with this binding. If the condition evaluates to `true`, then this binding applies to the current request. If the condition evaluates to `false`, then this binding does not apply to the current request. However, a different role binding might grant the same role to one or more of the principals in this binding. To learn which resources support conditions in their IAM policies, see the [IAM documentation](https://cloud.google.com/iam/help/conditions/resource-policies)." } }, "id": "Binding", "description": "Associates `members`, or principals, with a `role`." }, "RuntimeConfig": { "description": "A RuntimeConfig resource is the primary resource in the Cloud RuntimeConfig service. A RuntimeConfig resource consists of metadata and a hierarchy of variables.", "properties": { "description": { "description": "An optional description of the RuntimeConfig object.", "type": "string" }, "name": { "type": "string", "description": "The resource name of a runtime config. The name must have the format: projects/[PROJECT_ID]/configs/[CONFIG_NAME] The `[PROJECT_ID]` must be a valid project ID, and `[CONFIG_NAME]` is an arbitrary name that matches the `[0-9A-Za-z](?:[_.A-Za-z0-9-]{0,62}[_.A-Za-z0-9])?` regular expression. The length of `[CONFIG_NAME]` must be less than 64 characters. You pick the RuntimeConfig resource name, but the server will validate that the name adheres to this format. After you create the resource, you cannot change the resource's name." } }, "type": "object", "id": "RuntimeConfig" }, "ListVariablesResponse": { "description": "Response for the `ListVariables()` method.", "id": "ListVariablesResponse", "properties": { "variables": { "items": { "$ref": "Variable" }, "type": "array", "description": "A list of variables and their values. The order of returned variable objects is arbitrary." }, "nextPageToken": { "description": "This token allows you to get the next page of results for list requests. If the number of results is larger than `pageSize`, use the `nextPageToken` as a value for the query parameter `pageToken` in the next list request. Subsequent list requests will have their own `nextPageToken` to continue paging through the results", "type": "string" } }, "type": "object" }, "WatchVariableRequest": { "description": "Request for the `WatchVariable()` method.", "properties": { "newerThan": { "description": "If specified, checks the current timestamp of the variable and if the current timestamp is newer than `newerThan` timestamp, the method returns immediately. If not specified or the variable has an older timestamp, the watcher waits for a the value to change before returning.", "format": "google-datetime", "type": "string" } }, "id": "WatchVariableRequest", "type": "object" }, "ListWaitersResponse": { "type": "object", "description": "Response for the `ListWaiters()` method. Order of returned waiter objects is arbitrary.", "properties": { "nextPageToken": { "type": "string", "description": "This token allows you to get the next page of results for list requests. If the number of results is larger than `pageSize`, use the `nextPageToken` as a value for the query parameter `pageToken` in the next list request. Subsequent list requests will have their own `nextPageToken` to continue paging through the results" }, "waiters": { "type": "array", "description": "Found waiters in the project.", "items": { "$ref": "Waiter" } } }, "id": "ListWaitersResponse" } }, "mtlsRootUrl": "https://runtimeconfig.mtls.googleapis.com/", "id": "runtimeconfig:v1beta1", "name": "runtimeconfig", "revision": "20220613", "icons": { "x32": "http://www.google.com/images/icons/product/search-32.gif", "x16": "http://www.google.com/images/icons/product/search-16.gif" }, "description": "The Runtime Configurator allows you to dynamically configure and expose variables through Google Cloud Platform. In addition, you can also set Watchers and Waiters that will watch for changes to your data and return based on certain conditions.", "parameters": { "fields": { "location": "query", "description": "Selector specifying which fields to include in a partial response.", "type": "string" }, "access_token": { "description": "OAuth access token.", "location": "query", "type": "string" }, "alt": { "enumDescriptions": [ "Responses with Content-Type of application/json", "Media download with context-dependent Content-Type", "Responses with Content-Type of application/x-protobuf" ], "enum": [ "json", "media", "proto" ], "type": "string", "location": "query", "description": "Data format for response.", "default": "json" }, "key": { "location": "query", "description": "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.", "type": "string" }, "uploadType": { "type": "string", "location": "query", "description": "Legacy upload protocol for media (e.g. \"media\", \"multipart\")." }, "quotaUser": { "description": "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.", "type": "string", "location": "query" }, "prettyPrint": { "location": "query", "type": "boolean", "default": "true", "description": "Returns response with indentations and line breaks." }, "$.xgafv": { "enum": [ "1", "2" ], "description": "V1 error format.", "type": "string", "location": "query", "enumDescriptions": [ "v1 error format", "v2 error format" ] }, "upload_protocol": { "location": "query", "type": "string", "description": "Upload protocol for media (e.g. \"raw\", \"multipart\")." }, "callback": { "location": "query", "description": "JSONP", "type": "string" }, "oauth_token": { "location": "query", "type": "string", "description": "OAuth 2.0 token for the current user." } }, "ownerDomain": "google.com", "baseUrl": "https://runtimeconfig.googleapis.com/", "fullyEncodeReservedExpansion": true, "resources": { "projects": { "resources": { "configs": { "resources": { "operations": { "methods": { "get": { "path": "v1beta1/{+name}", "flatPath": "v1beta1/projects/{projectsId}/configs/{configsId}/operations/{operationsId}", "httpMethod": "GET", "response": { "$ref": "Operation" }, "id": "runtimeconfig.projects.configs.operations.get", "scopes": [ "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloudruntimeconfig" ], "parameters": { "name": { "type": "string", "description": "The name of the operation resource.", "location": "path", "pattern": "^projects/[^/]+/configs/[^/]+/operations/.*$", "required": true } }, "parameterOrder": [ "name" ], "description": "Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service." }, "testIamPermissions": { "path": "v1beta1/{+resource}:testIamPermissions", "flatPath": "v1beta1/projects/{projectsId}/configs/{configsId}/operations/{operationsId}:testIamPermissions", "response": { "$ref": "TestIamPermissionsResponse" }, "request": { "$ref": "TestIamPermissionsRequest" }, "id": "runtimeconfig.projects.configs.operations.testIamPermissions", "description": "Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a `NOT_FOUND` error. Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may \"fail open\" without warning.", "scopes": [ "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloudruntimeconfig" ], "parameterOrder": [ "resource" ], "parameters": { "resource": { "description": "REQUIRED: The resource for which the policy detail is being requested. See [Resource names](https://cloud.google.com/apis/design/resource_names) for the appropriate value for this field.", "type": "string", "location": "path", "pattern": "^projects/[^/]+/configs/[^/]+/operations/.*$", "required": true } }, "httpMethod": "POST" } } }, "waiters": { "methods": { "get": { "flatPath": "v1beta1/projects/{projectsId}/configs/{configsId}/waiters/{waitersId}", "path": "v1beta1/{+name}", "id": "runtimeconfig.projects.configs.waiters.get", "parameterOrder": [ "name" ], "description": "Gets information about a single waiter.", "response": { "$ref": "Waiter" }, "parameters": { "name": { "location": "path", "type": "string", "description": "The fully-qualified name of the Waiter resource object to retrieve, in the format: `projects/[PROJECT_ID]/configs/[CONFIG_NAME]/waiters/[WAITER_NAME]`", "pattern": "^projects/[^/]+/configs/[^/]+/waiters/[^/]+$", "required": true } }, "scopes": [ "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloudruntimeconfig" ], "httpMethod": "GET" }, "testIamPermissions": { "path": "v1beta1/{+resource}:testIamPermissions", "response": { "$ref": "TestIamPermissionsResponse" }, "parameterOrder": [ "resource" ], "request": { "$ref": "TestIamPermissionsRequest" }, "id": "runtimeconfig.projects.configs.waiters.testIamPermissions", "httpMethod": "POST", "flatPath": "v1beta1/projects/{projectsId}/configs/{configsId}/waiters/{waitersId}:testIamPermissions", "description": "Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a `NOT_FOUND` error. Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may \"fail open\" without warning.", "parameters": { "resource": { "description": "REQUIRED: The resource for which the policy detail is being requested. See [Resource names](https://cloud.google.com/apis/design/resource_names) for the appropriate value for this field.", "type": "string", "required": true, "pattern": "^projects/[^/]+/configs/[^/]+/waiters/[^/]+$", "location": "path" } }, "scopes": [ "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloudruntimeconfig" ] }, "list": { "parameterOrder": [ "parent" ], "scopes": [ "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloudruntimeconfig" ], "flatPath": "v1beta1/projects/{projectsId}/configs/{configsId}/waiters", "httpMethod": "GET", "id": "runtimeconfig.projects.configs.waiters.list", "path": "v1beta1/{+parent}/waiters", "parameters": { "pageToken": { "description": "Specifies a page token to use. Set `pageToken` to a `nextPageToken` returned by a previous list request to get the next page of results.", "type": "string", "location": "query" }, "parent": { "type": "string", "location": "path", "required": true, "pattern": "^projects/[^/]+/configs/[^/]+$", "description": "The path to the configuration for which you want to get a list of waiters. The configuration must exist beforehand; the path must be in the format: `projects/[PROJECT_ID]/configs/[CONFIG_NAME]`" }, "pageSize": { "location": "query", "type": "integer", "format": "int32", "description": "Specifies the number of results to return per page. If there are fewer elements than the specified number, returns all elements." } }, "response": { "$ref": "ListWaitersResponse" }, "description": "List waiters within the given configuration." }, "create": { "scopes": [ "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloudruntimeconfig" ], "description": "Creates a Waiter resource. This operation returns a long-running Operation resource which can be polled for completion. However, a waiter with the given name will exist (and can be retrieved) prior to the operation completing. If the operation fails, the failed Waiter resource will still exist and must be deleted prior to subsequent creation attempts.", "parameterOrder": [ "parent" ], "path": "v1beta1/{+parent}/waiters", "flatPath": "v1beta1/projects/{projectsId}/configs/{configsId}/waiters", "response": { "$ref": "Operation" }, "parameters": { "requestId": { "location": "query", "type": "string", "description": "An optional but recommended unique `request_id`. If the server receives two `create()` requests with the same `request_id`, then the second request will be ignored and the first resource created and stored in the backend is returned. Empty `request_id` fields are ignored. It is responsibility of the client to ensure uniqueness of the `request_id` strings. `request_id` strings are limited to 64 characters." }, "parent": { "location": "path", "pattern": "^projects/[^/]+/configs/[^/]+$", "required": true, "type": "string", "description": "The path to the configuration that will own the waiter. The configuration must exist beforehand; the path must be in the format: `projects/[PROJECT_ID]/configs/[CONFIG_NAME]`." } }, "request": { "$ref": "Waiter" }, "httpMethod": "POST", "id": "runtimeconfig.projects.configs.waiters.create" }, "delete": { "id": "runtimeconfig.projects.configs.waiters.delete", "response": { "$ref": "Empty" }, "httpMethod": "DELETE", "scopes": [ "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloudruntimeconfig" ], "parameterOrder": [ "name" ], "parameters": { "name": { "description": "The Waiter resource to delete, in the format: `projects/[PROJECT_ID]/configs/[CONFIG_NAME]/waiters/[WAITER_NAME]`", "pattern": "^projects/[^/]+/configs/[^/]+/waiters/[^/]+$", "location": "path", "required": true, "type": "string" } }, "flatPath": "v1beta1/projects/{projectsId}/configs/{configsId}/waiters/{waitersId}", "path": "v1beta1/{+name}", "description": "Deletes the waiter with the specified name." } } }, "variables": { "methods": { "list": { "flatPath": "v1beta1/projects/{projectsId}/configs/{configsId}/variables", "parameterOrder": [ "parent" ], "id": "runtimeconfig.projects.configs.variables.list", "httpMethod": "GET", "path": "v1beta1/{+parent}/variables", "parameters": { "filter": { "description": "Filters variables by matching the specified filter. For example: `projects/example-project/config/[CONFIG_NAME]/variables/example-variable`.", "type": "string", "location": "query" }, "pageToken": { "description": "Specifies a page token to use. Set `pageToken` to a `nextPageToken` returned by a previous list request to get the next page of results.", "location": "query", "type": "string" }, "pageSize": { "type": "integer", "location": "query", "format": "int32", "description": "Specifies the number of results to return per page. If there are fewer elements than the specified number, returns all elements." }, "returnValues": { "description": "The flag indicates whether the user wants to return values of variables. If true, then only those variables that user has IAM GetVariable permission will be returned along with their values.", "location": "query", "type": "boolean" }, "parent": { "location": "path", "pattern": "^projects/[^/]+/configs/[^/]+$", "type": "string", "required": true, "description": "The path to the RuntimeConfig resource for which you want to list variables. The configuration must exist beforehand; the path must be in the format: `projects/[PROJECT_ID]/configs/[CONFIG_NAME]`" } }, "description": "Lists variables within given a configuration, matching any provided filters. This only lists variable names, not the values, unless `return_values` is true, in which case only variables that user has IAM permission to GetVariable will be returned.", "response": { "$ref": "ListVariablesResponse" }, "scopes": [ "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloudruntimeconfig" ] }, "watch": { "response": { "$ref": "Variable" }, "parameterOrder": [ "name" ], "description": "Watches a specific variable and waits for a change in the variable's value. When there is a change, this method returns the new value or times out. If a variable is deleted while being watched, the `variableState` state is set to `DELETED` and the method returns the last known variable `value`. If you set the deadline for watching to a larger value than internal timeout (60 seconds), the current variable value is returned and the `variableState` will be `VARIABLE_STATE_UNSPECIFIED`. To learn more about creating a watcher, read the [Watching a Variable for Changes](/deployment-manager/runtime-configurator/watching-a-variable) documentation.", "scopes": [ "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloudruntimeconfig" ], "path": "v1beta1/{+name}:watch", "httpMethod": "POST", "request": { "$ref": "WatchVariableRequest" }, "flatPath": "v1beta1/projects/{projectsId}/configs/{configsId}/variables/{variablesId}:watch", "id": "runtimeconfig.projects.configs.variables.watch", "parameters": { "name": { "pattern": "^projects/[^/]+/configs/[^/]+/variables/.*$", "required": true, "description": "The name of the variable to watch, in the format: `projects/[PROJECT_ID]/configs/[CONFIG_NAME]`", "location": "path", "type": "string" } } }, "create": { "parameterOrder": [ "parent" ], "response": { "$ref": "Variable" }, "request": { "$ref": "Variable" }, "flatPath": "v1beta1/projects/{projectsId}/configs/{configsId}/variables", "id": "runtimeconfig.projects.configs.variables.create", "scopes": [ "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloudruntimeconfig" ], "path": "v1beta1/{+parent}/variables", "description": "Creates a variable within the given configuration. You cannot create a variable with a name that is a prefix of an existing variable name, or a name that has an existing variable name as a prefix. To learn more about creating a variable, read the [Setting and Getting Data](/deployment-manager/runtime-configurator/set-and-get-variables) documentation.", "httpMethod": "POST", "parameters": { "requestId": { "location": "query", "type": "string", "description": "An optional but recommended unique `request_id`. If the server receives two `create()` requests with the same `request_id`, then the second request will be ignored and the first resource created and stored in the backend is returned. Empty `request_id` fields are ignored. It is responsibility of the client to ensure uniqueness of the `request_id` strings. `request_id` strings are limited to 64 characters." }, "parent": { "type": "string", "required": true, "description": "The path to the RutimeConfig resource that this variable should belong to. The configuration must exist beforehand; the path must be in the format: `projects/[PROJECT_ID]/configs/[CONFIG_NAME]`", "location": "path", "pattern": "^projects/[^/]+/configs/[^/]+$" } } }, "delete": { "scopes": [ "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloudruntimeconfig" ], "flatPath": "v1beta1/projects/{projectsId}/configs/{configsId}/variables/{variablesId}", "id": "runtimeconfig.projects.configs.variables.delete", "parameterOrder": [ "name" ], "httpMethod": "DELETE", "response": { "$ref": "Empty" }, "path": "v1beta1/{+name}", "description": "Deletes a variable or multiple variables. If you specify a variable name, then that variable is deleted. If you specify a prefix and `recursive` is true, then all variables with that prefix are deleted. You must set a `recursive` to true if you delete variables by prefix.", "parameters": { "name": { "pattern": "^projects/[^/]+/configs/[^/]+/variables/.*$", "description": "The name of the variable to delete, in the format: `projects/[PROJECT_ID]/configs/[CONFIG_NAME]/variables/[VARIABLE_NAME]`", "location": "path", "type": "string", "required": true }, "recursive": { "location": "query", "description": "Set to `true` to recursively delete multiple variables with the same prefix.", "type": "boolean" } } }, "testIamPermissions": { "parameterOrder": [ "resource" ], "flatPath": "v1beta1/projects/{projectsId}/configs/{configsId}/variables/{variablesId}:testIamPermissions", "parameters": { "resource": { "pattern": "^projects/[^/]+/configs/[^/]+/variables/.*$", "type": "string", "description": "REQUIRED: The resource for which the policy detail is being requested. See [Resource names](https://cloud.google.com/apis/design/resource_names) for the appropriate value for this field.", "required": true, "location": "path" } }, "scopes": [ "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloudruntimeconfig" ], "id": "runtimeconfig.projects.configs.variables.testIamPermissions", "description": "Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a `NOT_FOUND` error. Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may \"fail open\" without warning.", "response": { "$ref": "TestIamPermissionsResponse" }, "request": { "$ref": "TestIamPermissionsRequest" }, "httpMethod": "POST", "path": "v1beta1/{+resource}:testIamPermissions" }, "update": { "parameters": { "name": { "type": "string", "location": "path", "required": true, "pattern": "^projects/[^/]+/configs/[^/]+/variables/.*$", "description": "The name of the variable to update, in the format: `projects/[PROJECT_ID]/configs/[CONFIG_NAME]/variables/[VARIABLE_NAME]`" } }, "scopes": [ "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloudruntimeconfig" ], "id": "runtimeconfig.projects.configs.variables.update", "httpMethod": "PUT", "request": { "$ref": "Variable" }, "path": "v1beta1/{+name}", "response": { "$ref": "Variable" }, "flatPath": "v1beta1/projects/{projectsId}/configs/{configsId}/variables/{variablesId}", "description": "Updates an existing variable with a new value.", "parameterOrder": [ "name" ] }, "get": { "path": "v1beta1/{+name}", "httpMethod": "GET", "parameters": { "name": { "required": true, "location": "path", "type": "string", "description": "The name of the variable to return, in the format: `projects/[PROJECT_ID]/configs/[CONFIG_NAME]/variables/[VARIBLE_NAME]`", "pattern": "^projects/[^/]+/configs/[^/]+/variables/.*$" } }, "description": "Gets information about a single variable.", "parameterOrder": [ "name" ], "flatPath": "v1beta1/projects/{projectsId}/configs/{configsId}/variables/{variablesId}", "id": "runtimeconfig.projects.configs.variables.get", "scopes": [ "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloudruntimeconfig" ], "response": { "$ref": "Variable" } } } } }, "methods": { "update": { "flatPath": "v1beta1/projects/{projectsId}/configs/{configsId}", "request": { "$ref": "RuntimeConfig" }, "parameters": { "name": { "description": "The name of the RuntimeConfig resource to update, in the format: `projects/[PROJECT_ID]/configs/[CONFIG_NAME]`", "type": "string", "location": "path", "required": true, "pattern": "^projects/[^/]+/configs/[^/]+$" } }, "path": "v1beta1/{+name}", "httpMethod": "PUT", "scopes": [ "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloudruntimeconfig" ], "description": "Updates a RuntimeConfig resource. The configuration must exist beforehand.", "parameterOrder": [ "name" ], "response": { "$ref": "RuntimeConfig" }, "id": "runtimeconfig.projects.configs.update" }, "list": { "parameterOrder": [ "parent" ], "parameters": { "pageToken": { "type": "string", "location": "query", "description": "Specifies a page token to use. Set `pageToken` to a `nextPageToken` returned by a previous list request to get the next page of results." }, "pageSize": { "type": "integer", "location": "query", "format": "int32", "description": "Specifies the number of results to return per page. If there are fewer elements than the specified number, returns all elements." }, "parent": { "location": "path", "description": "The [project ID](https://support.google.com/cloud/answer/6158840?hl=en&ref_topic=6158848) for this request, in the format `projects/[PROJECT_ID]`.", "required": true, "pattern": "^projects/[^/]+$", "type": "string" } }, "scopes": [ "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloudruntimeconfig" ], "id": "runtimeconfig.projects.configs.list", "flatPath": "v1beta1/projects/{projectsId}/configs", "httpMethod": "GET", "description": "Lists all the RuntimeConfig resources within project.", "response": { "$ref": "ListConfigsResponse" }, "path": "v1beta1/{+parent}/configs" }, "setIamPolicy": { "scopes": [ "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloudruntimeconfig" ], "httpMethod": "POST", "description": "Sets the access control policy on the specified resource. Replaces any existing policy. Can return `NOT_FOUND`, `INVALID_ARGUMENT`, and `PERMISSION_DENIED` errors.", "parameters": { "resource": { "required": true, "description": "REQUIRED: The resource for which the policy is being specified. See [Resource names](https://cloud.google.com/apis/design/resource_names) for the appropriate value for this field.", "location": "path", "pattern": "^projects/[^/]+/configs/[^/]+$", "type": "string" } }, "parameterOrder": [ "resource" ], "flatPath": "v1beta1/projects/{projectsId}/configs/{configsId}:setIamPolicy", "response": { "$ref": "Policy" }, "path": "v1beta1/{+resource}:setIamPolicy", "id": "runtimeconfig.projects.configs.setIamPolicy", "request": { "$ref": "SetIamPolicyRequest" } }, "delete": { "description": "Deletes a RuntimeConfig resource.", "parameterOrder": [ "name" ], "id": "runtimeconfig.projects.configs.delete", "scopes": [ "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloudruntimeconfig" ], "parameters": { "name": { "required": true, "pattern": "^projects/[^/]+/configs/[^/]+$", "description": "The RuntimeConfig resource to delete, in the format: `projects/[PROJECT_ID]/configs/[CONFIG_NAME]`", "type": "string", "location": "path" } }, "response": { "$ref": "Empty" }, "flatPath": "v1beta1/projects/{projectsId}/configs/{configsId}", "path": "v1beta1/{+name}", "httpMethod": "DELETE" }, "getIamPolicy": { "scopes": [ "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloudruntimeconfig" ], "description": "Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.", "flatPath": "v1beta1/projects/{projectsId}/configs/{configsId}:getIamPolicy", "id": "runtimeconfig.projects.configs.getIamPolicy", "parameterOrder": [ "resource" ], "path": "v1beta1/{+resource}:getIamPolicy", "httpMethod": "GET", "parameters": { "options.requestedPolicyVersion": { "description": "Optional. The maximum policy version that will be used to format the policy. Valid values are 0, 1, and 3. Requests specifying an invalid value will be rejected. Requests for policies with any conditional role bindings must specify version 3. Policies with no conditional role bindings may specify any valid value or leave the field unset. The policy in the response might use the policy version that you specified, or it might use a lower policy version. For example, if you specify version 3, but the policy has no conditional role bindings, the response uses version 1. To learn which resources support conditions in their IAM policies, see the [IAM documentation](https://cloud.google.com/iam/help/conditions/resource-policies).", "format": "int32", "type": "integer", "location": "query" }, "resource": { "type": "string", "required": true, "description": "REQUIRED: The resource for which the policy is being requested. See [Resource names](https://cloud.google.com/apis/design/resource_names) for the appropriate value for this field.", "pattern": "^projects/[^/]+/configs/[^/]+$", "location": "path" } }, "response": { "$ref": "Policy" } }, "testIamPermissions": { "path": "v1beta1/{+resource}:testIamPermissions", "request": { "$ref": "TestIamPermissionsRequest" }, "httpMethod": "POST", "id": "runtimeconfig.projects.configs.testIamPermissions", "flatPath": "v1beta1/projects/{projectsId}/configs/{configsId}:testIamPermissions", "parameters": { "resource": { "required": true, "type": "string", "location": "path", "pattern": "^projects/[^/]+/configs/[^/]+$", "description": "REQUIRED: The resource for which the policy detail is being requested. See [Resource names](https://cloud.google.com/apis/design/resource_names) for the appropriate value for this field." } }, "description": "Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a `NOT_FOUND` error. Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may \"fail open\" without warning.", "response": { "$ref": "TestIamPermissionsResponse" }, "parameterOrder": [ "resource" ], "scopes": [ "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloudruntimeconfig" ] }, "get": { "path": "v1beta1/{+name}", "description": "Gets information about a RuntimeConfig resource.", "parameters": { "name": { "location": "path", "pattern": "^projects/[^/]+/configs/[^/]+$", "description": "The name of the RuntimeConfig resource to retrieve, in the format: `projects/[PROJECT_ID]/configs/[CONFIG_NAME]`", "required": true, "type": "string" } }, "httpMethod": "GET", "response": { "$ref": "RuntimeConfig" }, "scopes": [ "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloudruntimeconfig" ], "flatPath": "v1beta1/projects/{projectsId}/configs/{configsId}", "parameterOrder": [ "name" ], "id": "runtimeconfig.projects.configs.get" }, "create": { "request": { "$ref": "RuntimeConfig" }, "httpMethod": "POST", "description": "Creates a new RuntimeConfig resource. The configuration name must be unique within project.", "response": { "$ref": "RuntimeConfig" }, "parameterOrder": [ "parent" ], "parameters": { "parent": { "type": "string", "location": "path", "description": "The [project ID](https://support.google.com/cloud/answer/6158840?hl=en&ref_topic=6158848) for this request, in the format `projects/[PROJECT_ID]`.", "pattern": "^projects/[^/]+$", "required": true }, "requestId": { "type": "string", "location": "query", "description": "An optional but recommended unique `request_id`. If the server receives two `create()` requests with the same `request_id`, then the second request will be ignored and the first resource created and stored in the backend is returned. Empty `request_id` fields are ignored. It is responsibility of the client to ensure uniqueness of the `request_id` strings. `request_id` strings are limited to 64 characters." } }, "scopes": [ "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloudruntimeconfig" ], "id": "runtimeconfig.projects.configs.create", "flatPath": "v1beta1/projects/{projectsId}/configs", "path": "v1beta1/{+parent}/configs" } } } } } }, "servicePath": "", "discoveryVersion": "v1", "basePath": "", "version": "v1beta1", "batchPath": "batch", "kind": "discovery#restDescription", "rootUrl": "https://runtimeconfig.googleapis.com/", "title": "Cloud Runtime Configuration API", "canonicalName": "Cloud RuntimeConfig", "version_module": true, "documentationLink": "https://cloud.google.com/deployment-manager/runtime-configurator/", "auth": { "oauth2": { "scopes": { "https://www.googleapis.com/auth/cloudruntimeconfig": { "description": "Manage your Google Cloud Platform services' runtime configuration" }, "https://www.googleapis.com/auth/cloud-platform": { "description": "See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account." } } } } }
]===]))
