local decode = require("cjson").new().decode
return assert(decode([===[
{ "schemas": { "GoogleAccount": { "type": "object", "id": "GoogleAccount", "description": "Describes authentication configuration that uses a Google account.", "properties": { "username": { "description": "Required. The user name of the Google account.", "type": "string" }, "password": { "description": "Required. Input only. The password of the Google account. The credential is stored encrypted and not returned in any response nor included in audit logs.", "type": "string" } } }, "ScanConfig": { "properties": { "targetPlatforms": { "description": "Set of Google Cloud platforms targeted by the scan. If empty, APP_ENGINE will be used as a default.", "items": { "type": "string", "enumDescriptions": [ "The target platform is unknown. Requests with this enum value will be rejected with INVALID_ARGUMENT error.", "Google App Engine service.", "Google Compute Engine service.", "Google Cloud Run service.", "Google Cloud Function service." ], "enum": [ "TARGET_PLATFORM_UNSPECIFIED", "APP_ENGINE", "COMPUTE", "CLOUD_RUN", "CLOUD_FUNCTIONS" ] }, "type": "array" }, "displayName": { "type": "string", "description": "Required. The user provided display name of the ScanConfig." }, "userAgent": { "type": "string", "description": "The user agent used during scanning.", "enum": [ "USER_AGENT_UNSPECIFIED", "CHROME_LINUX", "CHROME_ANDROID", "SAFARI_IPHONE" ], "enumDescriptions": [ "The user agent is unknown. Service will default to CHROME_LINUX.", "Chrome on Linux. This is the service default if unspecified.", "Chrome on Android.", "Safari on IPhone." ] }, "authentication": { "description": "The authentication configuration. If specified, service will use the authentication configuration during scanning.", "$ref": "Authentication" }, "blacklistPatterns": { "items": { "type": "string" }, "description": "The excluded URL patterns as described in https://cloud.google.com/security-command-center/docs/how-to-use-web-security-scanner#excluding_urls", "type": "array" }, "maxQps": { "type": "integer", "format": "int32", "description": "The maximum QPS during scanning. A valid value ranges from 5 to 20 inclusively. If the field is unspecified or its value is set 0, server will default to 15. Other values outside of [5, 20] range will be rejected with INVALID_ARGUMENT error." }, "name": { "description": "The resource name of the ScanConfig. The name follows the format of 'projects/{projectId}/scanConfigs/{scanConfigId}'. The ScanConfig IDs are generated by the system.", "type": "string" }, "latestRun": { "$ref": "ScanRun", "description": "Latest ScanRun if available." }, "schedule": { "$ref": "Schedule", "description": "The schedule of the ScanConfig." }, "startingUrls": { "description": "Required. The starting URLs from which the scanner finds site pages.", "type": "array", "items": { "type": "string" } } }, "type": "object", "description": "A ScanConfig resource contains the configurations to launch a scan. next id: 12", "id": "ScanConfig" }, "OutdatedLibrary": { "properties": { "libraryName": { "description": "The name of the outdated library.", "type": "string" }, "learnMoreUrls": { "items": { "type": "string" }, "description": "URLs to learn more information about the vulnerabilities in the library.", "type": "array" }, "version": { "description": "The version number.", "type": "string" } }, "id": "OutdatedLibrary", "type": "object", "description": "Information reported for an outdated library." }, "StopScanRunRequest": { "type": "object", "description": "Request for the `StopScanRun` method.", "id": "StopScanRunRequest", "properties": {} }, "Schedule": { "properties": { "scheduleTime": { "description": "A timestamp indicates when the next run will be scheduled. The value is refreshed by the server after each run. If unspecified, it will default to current server time, which means the scan will be scheduled to start immediately.", "format": "google-datetime", "type": "string" }, "intervalDurationDays": { "format": "int32", "type": "integer", "description": "Required. The duration of time between executions in days." } }, "id": "Schedule", "type": "object", "description": "Scan schedule configuration." }, "ListFindingTypeStatsResponse": { "description": "Response for the `ListFindingTypeStats` method.", "type": "object", "properties": { "findingTypeStats": { "items": { "$ref": "FindingTypeStats" }, "description": "The list of FindingTypeStats returned.", "type": "array" } }, "id": "ListFindingTypeStatsResponse" }, "Header": { "type": "object", "properties": { "name": { "description": "Header name.", "type": "string" }, "value": { "type": "string", "description": "Header value." } }, "description": "Describes a HTTP Header.", "id": "Header" }, "Finding": { "id": "Finding", "properties": { "xss": { "$ref": "Xss", "description": "An addon containing information reported for an XSS, if any." }, "outdatedLibrary": { "description": "An addon containing information about outdated libraries.", "$ref": "OutdatedLibrary" }, "name": { "type": "string", "description": "The resource name of the Finding. The name follows the format of 'projects/{projectId}/scanConfigs/{scanConfigId}/scanruns/{scanRunId}/findings/{findingId}'. The finding IDs are generated by the system." }, "fuzzedUrl": { "description": "The URL produced by the server-side fuzzer and used in the request that triggered the vulnerability.", "type": "string" }, "vulnerableHeaders": { "$ref": "VulnerableHeaders", "description": "An addon containing information about vulnerable or missing HTTP headers." }, "frameUrl": { "description": "If the vulnerability was originated from nested IFrame, the immediate parent IFrame is reported.", "type": "string" }, "body": { "type": "string", "description": "The body of the request that triggered the vulnerability." }, "reproductionUrl": { "type": "string", "description": "The URL containing human-readable payload that user can leverage to reproduce the vulnerability." }, "description": { "description": "The description of the vulnerability.", "type": "string" }, "trackingId": { "description": "The tracking ID uniquely identifies a vulnerability instance across multiple ScanRuns.", "type": "string" }, "findingType": { "type": "string", "enum": [ "FINDING_TYPE_UNSPECIFIED", "MIXED_CONTENT", "OUTDATED_LIBRARY", "ROSETTA_FLASH", "XSS_CALLBACK", "XSS_ERROR", "CLEAR_TEXT_PASSWORD", "INVALID_CONTENT_TYPE", "XSS_ANGULAR_CALLBACK", "INVALID_HEADER", "MISSPELLED_SECURITY_HEADER_NAME", "MISMATCHING_SECURITY_HEADER_VALUES" ], "enumDescriptions": [ "The invalid finding type.", "A page that was served over HTTPS also resources over HTTP. A man-in-the-middle attacker could tamper with the HTTP resource and gain full access to the website that loads the resource or to monitor the actions taken by the user.", "The version of an included library is known to contain a security issue. The scanner checks the version of library in use against a known list of vulnerable libraries. False positives are possible if the version detection fails or if the library has been manually patched.", "This type of vulnerability occurs when the value of a request parameter is reflected at the beginning of the response, for example, in requests using JSONP. Under certain circumstances, an attacker may be able to supply an alphanumeric-only Flash file in the vulnerable parameter causing the browser to execute the Flash file as if it originated on the vulnerable server.", "A cross-site scripting (XSS) bug is found via JavaScript callback. For detailed explanations on XSS, see https://www.google.com/about/appsecurity/learning/xss/.", "A potential cross-site scripting (XSS) bug due to JavaScript breakage. In some circumstances, the application under test might modify the test string before it is parsed by the browser. When the browser attempts to runs this modified test string, it will likely break and throw a JavaScript execution error, thus an injection issue is occurring. However, it may not be exploitable. Manual verification is needed to see if the test string modifications can be evaded and confirm that the issue is in fact an XSS vulnerability. For detailed explanations on XSS, see https://www.google.com/about/appsecurity/learning/xss/.", "An application appears to be transmitting a password field in clear text. An attacker can eavesdrop network traffic and sniff the password field.", "An application returns sensitive content with an invalid content type, or without an 'X-Content-Type-Options: nosniff' header.", "A cross-site scripting (XSS) vulnerability in AngularJS module that occurs when a user-provided string is interpolated by Angular.", "A malformed or invalid valued header.", "Misspelled security header name.", "Mismatching values in a duplicate security header." ], "description": "The type of the Finding." }, "vulnerableParameters": { "description": "An addon containing information about request parameters which were found to be vulnerable.", "$ref": "VulnerableParameters" }, "violatingResource": { "description": "An addon containing detailed information regarding any resource causing the vulnerability such as JavaScript sources, image, audio files, etc.", "$ref": "ViolatingResource" }, "httpMethod": { "description": "The http method of the request that triggered the vulnerability, in uppercase.", "type": "string" }, "finalUrl": { "description": "The URL where the browser lands when the vulnerability is detected.", "type": "string" } }, "description": "A Finding resource represents a vulnerability instance identified during a ScanRun.", "type": "object" }, "ListScanConfigsResponse": { "id": "ListScanConfigsResponse", "type": "object", "properties": { "nextPageToken": { "type": "string", "description": "Token to retrieve the next page of results, or empty if there are no more results in the list." }, "scanConfigs": { "description": "The list of ScanConfigs returned.", "type": "array", "items": { "$ref": "ScanConfig" } } }, "description": "Response for the `ListScanConfigs` method." }, "VulnerableHeaders": { "properties": { "missingHeaders": { "items": { "$ref": "Header" }, "description": "List of missing headers.", "type": "array" }, "headers": { "description": "List of vulnerable headers.", "type": "array", "items": { "$ref": "Header" } } }, "type": "object", "id": "VulnerableHeaders", "description": "Information about vulnerable or missing HTTP Headers." }, "Empty": { "description": "A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance: service Foo { rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty); }", "properties": {}, "id": "Empty", "type": "object" }, "Xss": { "description": "Information reported for an XSS.", "id": "Xss", "type": "object", "properties": { "stackTraces": { "description": "Stack traces leading to the point where the XSS occurred.", "items": { "type": "string" }, "type": "array" }, "errorMessage": { "description": "An error message generated by a javascript breakage.", "type": "string" } } }, "ScanRun": { "description": "A ScanRun is a output-only resource representing an actual run of the scan.", "properties": { "hasVulnerabilities": { "type": "boolean", "description": "Whether the scan run has found any vulnerabilities." }, "progressPercent": { "format": "int32", "description": "The percentage of total completion ranging from 0 to 100. If the scan is in queue, the value is 0. If the scan is running, the value ranges from 0 to 100. If the scan is finished, the value is 100.", "type": "integer" }, "executionState": { "description": "The execution state of the ScanRun.", "type": "string", "enumDescriptions": [ "Represents an invalid state caused by internal server error. This value should never be returned.", "The scan is waiting in the queue.", "The scan is in progress.", "The scan is either finished or stopped by user." ], "enum": [ "EXECUTION_STATE_UNSPECIFIED", "QUEUED", "SCANNING", "FINISHED" ] }, "urlsTestedCount": { "description": "The number of URLs tested during this ScanRun. If the scan is in progress, the value represents the number of URLs tested up to now. The number of URLs tested is usually larger than the number URLS crawled because typically a crawled URL is tested with multiple test payloads.", "format": "int64", "type": "string" }, "urlsCrawledCount": { "description": "The number of URLs crawled during this ScanRun. If the scan is in progress, the value represents the number of URLs crawled up to now.", "type": "string", "format": "int64" }, "name": { "type": "string", "description": "The resource name of the ScanRun. The name follows the format of 'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'. The ScanRun IDs are generated by the system." }, "startTime": { "type": "string", "format": "google-datetime", "description": "The time at which the ScanRun started." }, "endTime": { "type": "string", "description": "The time at which the ScanRun reached termination state - that the ScanRun is either finished or stopped by user.", "format": "google-datetime" }, "resultState": { "type": "string", "description": "The result state of the ScanRun. This field is only available after the execution state reaches \"FINISHED\".", "enum": [ "RESULT_STATE_UNSPECIFIED", "SUCCESS", "ERROR", "KILLED" ], "enumDescriptions": [ "Default value. This value is returned when the ScanRun is not yet finished.", "The scan finished without errors.", "The scan finished with errors.", "The scan was terminated by user." ] } }, "type": "object", "id": "ScanRun" }, "ListScanRunsResponse": { "id": "ListScanRunsResponse", "description": "Response for the `ListScanRuns` method.", "properties": { "scanRuns": { "description": "The list of ScanRuns returned.", "type": "array", "items": { "$ref": "ScanRun" } }, "nextPageToken": { "type": "string", "description": "Token to retrieve the next page of results, or empty if there are no more results in the list." } }, "type": "object" }, "VulnerableParameters": { "description": "Information about vulnerable request parameters.", "id": "VulnerableParameters", "type": "object", "properties": { "parameterNames": { "description": "The vulnerable parameter names.", "type": "array", "items": { "type": "string" } } } }, "ViolatingResource": { "id": "ViolatingResource", "type": "object", "properties": { "contentType": { "description": "The MIME type of this resource.", "type": "string" }, "resourceUrl": { "type": "string", "description": "URL of this violating resource." } }, "description": "Information regarding any resource causing the vulnerability such as JavaScript sources, image, audio files, etc." }, "ListFindingsResponse": { "description": "Response for the `ListFindings` method.", "id": "ListFindingsResponse", "type": "object", "properties": { "findings": { "description": "The list of Findings returned.", "items": { "$ref": "Finding" }, "type": "array" }, "nextPageToken": { "type": "string", "description": "Token to retrieve the next page of results, or empty if there are no more results in the list." } } }, "CrawledUrl": { "properties": { "url": { "description": "Output only. The URL that was crawled.", "type": "string" }, "body": { "type": "string", "description": "Output only. The body of the request that was used to visit the URL." }, "httpMethod": { "type": "string", "description": "Output only. The http method of the request that was used to visit the URL, in uppercase." } }, "description": "A CrawledUrl resource represents a URL that was crawled during a ScanRun. Web Security Scanner Service crawls the web applications, following all links within the scope of sites, to find the URLs to test against.", "id": "CrawledUrl", "type": "object" }, "Authentication": { "id": "Authentication", "type": "object", "properties": { "customAccount": { "$ref": "CustomAccount", "description": "Authentication using a custom account." }, "googleAccount": { "$ref": "GoogleAccount", "description": "Authentication using a Google account." } }, "description": "Scan authentication configuration." }, "FindingTypeStats": { "description": "A FindingTypeStats resource represents stats regarding a specific FindingType of Findings under a given ScanRun.", "id": "FindingTypeStats", "type": "object", "properties": { "findingType": { "description": "The finding type associated with the stats.", "type": "string", "enumDescriptions": [ "The invalid finding type.", "A page that was served over HTTPS also resources over HTTP. A man-in-the-middle attacker could tamper with the HTTP resource and gain full access to the website that loads the resource or to monitor the actions taken by the user.", "The version of an included library is known to contain a security issue. The scanner checks the version of library in use against a known list of vulnerable libraries. False positives are possible if the version detection fails or if the library has been manually patched.", "This type of vulnerability occurs when the value of a request parameter is reflected at the beginning of the response, for example, in requests using JSONP. Under certain circumstances, an attacker may be able to supply an alphanumeric-only Flash file in the vulnerable parameter causing the browser to execute the Flash file as if it originated on the vulnerable server.", "A cross-site scripting (XSS) bug is found via JavaScript callback. For detailed explanations on XSS, see https://www.google.com/about/appsecurity/learning/xss/.", "A potential cross-site scripting (XSS) bug due to JavaScript breakage. In some circumstances, the application under test might modify the test string before it is parsed by the browser. When the browser attempts to runs this modified test string, it will likely break and throw a JavaScript execution error, thus an injection issue is occurring. However, it may not be exploitable. Manual verification is needed to see if the test string modifications can be evaded and confirm that the issue is in fact an XSS vulnerability. For detailed explanations on XSS, see https://www.google.com/about/appsecurity/learning/xss/.", "An application appears to be transmitting a password field in clear text. An attacker can eavesdrop network traffic and sniff the password field.", "An application returns sensitive content with an invalid content type, or without an 'X-Content-Type-Options: nosniff' header.", "A cross-site scripting (XSS) vulnerability in AngularJS module that occurs when a user-provided string is interpolated by Angular.", "A malformed or invalid valued header.", "Misspelled security header name.", "Mismatching values in a duplicate security header." ], "enum": [ "FINDING_TYPE_UNSPECIFIED", "MIXED_CONTENT", "OUTDATED_LIBRARY", "ROSETTA_FLASH", "XSS_CALLBACK", "XSS_ERROR", "CLEAR_TEXT_PASSWORD", "INVALID_CONTENT_TYPE", "XSS_ANGULAR_CALLBACK", "INVALID_HEADER", "MISSPELLED_SECURITY_HEADER_NAME", "MISMATCHING_SECURITY_HEADER_VALUES" ] }, "findingCount": { "format": "int32", "description": "The count of findings belonging to this finding type.", "type": "integer" } } }, "StartScanRunRequest": { "properties": {}, "id": "StartScanRunRequest", "description": "Request for the `StartScanRun` method.", "type": "object" }, "CustomAccount": { "id": "CustomAccount", "description": "Describes authentication configuration that uses a custom account.", "type": "object", "properties": { "username": { "type": "string", "description": "Required. The user name of the custom account." }, "loginUrl": { "description": "Required. The login form URL of the website.", "type": "string" }, "password": { "description": "Required. Input only. The password of the custom account. The credential is stored encrypted and not returned in any response nor included in audit logs.", "type": "string" } } }, "ListCrawledUrlsResponse": { "type": "object", "description": "Response for the `ListCrawledUrls` method.", "properties": { "crawledUrls": { "type": "array", "items": { "$ref": "CrawledUrl" }, "description": "The list of CrawledUrls returned." }, "nextPageToken": { "description": "Token to retrieve the next page of results, or empty if there are no more results in the list.", "type": "string" } }, "id": "ListCrawledUrlsResponse" } }, "ownerDomain": "google.com", "servicePath": "", "protocol": "rest", "discoveryVersion": "v1", "baseUrl": "https://websecurityscanner.googleapis.com/", "basePath": "", "kind": "discovery#restDescription", "parameters": { "callback": { "type": "string", "description": "JSONP", "location": "query" }, "$.xgafv": { "type": "string", "description": "V1 error format.", "enumDescriptions": [ "v1 error format", "v2 error format" ], "enum": [ "1", "2" ], "location": "query" }, "prettyPrint": { "default": "true", "type": "boolean", "description": "Returns response with indentations and line breaks.", "location": "query" }, "uploadType": { "location": "query", "description": "Legacy upload protocol for media (e.g. \"media\", \"multipart\").", "type": "string" }, "alt": { "default": "json", "location": "query", "enum": [ "json", "media", "proto" ], "description": "Data format for response.", "enumDescriptions": [ "Responses with Content-Type of application/json", "Media download with context-dependent Content-Type", "Responses with Content-Type of application/x-protobuf" ], "type": "string" }, "quotaUser": { "location": "query", "description": "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.", "type": "string" }, "fields": { "description": "Selector specifying which fields to include in a partial response.", "location": "query", "type": "string" }, "access_token": { "location": "query", "type": "string", "description": "OAuth access token." }, "upload_protocol": { "description": "Upload protocol for media (e.g. \"raw\", \"multipart\").", "location": "query", "type": "string" }, "oauth_token": { "description": "OAuth 2.0 token for the current user.", "location": "query", "type": "string" }, "key": { "location": "query", "type": "string", "description": "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token." } }, "description": "Scans your Compute and App Engine apps for common web vulnerabilities.", "auth": { "oauth2": { "scopes": { "https://www.googleapis.com/auth/cloud-platform": { "description": "See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account." } } } }, "name": "websecurityscanner", "id": "websecurityscanner:v1alpha", "version": "v1alpha", "revision": "20220630", "ownerName": "Google", "resources": { "projects": { "resources": { "scanConfigs": { "methods": { "start": { "response": { "$ref": "ScanRun" }, "description": "Start a ScanRun according to the given ScanConfig.", "flatPath": "v1alpha/projects/{projectsId}/scanConfigs/{scanConfigsId}:start", "id": "websecurityscanner.projects.scanConfigs.start", "request": { "$ref": "StartScanRunRequest" }, "path": "v1alpha/{+name}:start", "parameters": { "name": { "description": "Required. The resource name of the ScanConfig to be used. The name follows the format of 'projects/{projectId}/scanConfigs/{scanConfigId}'.", "location": "path", "type": "string", "pattern": "^projects/[^/]+/scanConfigs/[^/]+$", "required": true } }, "parameterOrder": [ "name" ], "scopes": [ "https://www.googleapis.com/auth/cloud-platform" ], "httpMethod": "POST" }, "patch": { "parameterOrder": [ "name" ], "id": "websecurityscanner.projects.scanConfigs.patch", "parameters": { "updateMask": { "location": "query", "format": "google-fieldmask", "type": "string", "description": "Required. The update mask applies to the resource. For the `FieldMask` definition, see https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask" }, "name": { "required": true, "location": "path", "type": "string", "pattern": "^projects/[^/]+/scanConfigs/[^/]+$", "description": "The resource name of the ScanConfig. The name follows the format of 'projects/{projectId}/scanConfigs/{scanConfigId}'. The ScanConfig IDs are generated by the system." } }, "flatPath": "v1alpha/projects/{projectsId}/scanConfigs/{scanConfigsId}", "description": "Updates a ScanConfig. This method support partial update of a ScanConfig.", "path": "v1alpha/{+name}", "httpMethod": "PATCH", "response": { "$ref": "ScanConfig" }, "scopes": [ "https://www.googleapis.com/auth/cloud-platform" ], "request": { "$ref": "ScanConfig" } }, "create": { "response": { "$ref": "ScanConfig" }, "scopes": [ "https://www.googleapis.com/auth/cloud-platform" ], "flatPath": "v1alpha/projects/{projectsId}/scanConfigs", "request": { "$ref": "ScanConfig" }, "parameterOrder": [ "parent" ], "path": "v1alpha/{+parent}/scanConfigs", "id": "websecurityscanner.projects.scanConfigs.create", "parameters": { "parent": { "type": "string", "pattern": "^projects/[^/]+$", "description": "Required. The parent resource name where the scan is created, which should be a project resource name in the format 'projects/{projectId}'.", "location": "path", "required": true } }, "description": "Creates a new ScanConfig.", "httpMethod": "POST" }, "get": { "description": "Gets a ScanConfig.", "parameters": { "name": { "required": true, "description": "Required. The resource name of the ScanConfig to be returned. The name follows the format of 'projects/{projectId}/scanConfigs/{scanConfigId}'.", "location": "path", "type": "string", "pattern": "^projects/[^/]+/scanConfigs/[^/]+$" } }, "path": "v1alpha/{+name}", "response": { "$ref": "ScanConfig" }, "parameterOrder": [ "name" ], "flatPath": "v1alpha/projects/{projectsId}/scanConfigs/{scanConfigsId}", "scopes": [ "https://www.googleapis.com/auth/cloud-platform" ], "id": "websecurityscanner.projects.scanConfigs.get", "httpMethod": "GET" }, "delete": { "path": "v1alpha/{+name}", "parameters": { "name": { "pattern": "^projects/[^/]+/scanConfigs/[^/]+$", "type": "string", "description": "Required. The resource name of the ScanConfig to be deleted. The name follows the format of 'projects/{projectId}/scanConfigs/{scanConfigId}'.", "required": true, "location": "path" } }, "flatPath": "v1alpha/projects/{projectsId}/scanConfigs/{scanConfigsId}", "httpMethod": "DELETE", "description": "Deletes an existing ScanConfig and its child resources.", "id": "websecurityscanner.projects.scanConfigs.delete", "scopes": [ "https://www.googleapis.com/auth/cloud-platform" ], "parameterOrder": [ "name" ], "response": { "$ref": "Empty" } }, "list": { "scopes": [ "https://www.googleapis.com/auth/cloud-platform" ], "parameterOrder": [ "parent" ], "id": "websecurityscanner.projects.scanConfigs.list", "httpMethod": "GET", "path": "v1alpha/{+parent}/scanConfigs", "parameters": { "pageSize": { "format": "int32", "location": "query", "description": "The maximum number of ScanConfigs to return, can be limited by server. If not specified or not positive, the implementation will select a reasonable value.", "type": "integer" }, "parent": { "location": "path", "description": "Required. The parent resource name, which should be a project resource name in the format 'projects/{projectId}'.", "required": true, "pattern": "^projects/[^/]+$", "type": "string" }, "pageToken": { "location": "query", "description": "A token identifying a page of results to be returned. This should be a `next_page_token` value returned from a previous List request. If unspecified, the first page of results is returned.", "type": "string" } }, "flatPath": "v1alpha/projects/{projectsId}/scanConfigs", "response": { "$ref": "ListScanConfigsResponse" }, "description": "Lists ScanConfigs under a given project." } }, "resources": { "scanRuns": { "resources": { "findings": { "methods": { "list": { "scopes": [ "https://www.googleapis.com/auth/cloud-platform" ], "description": "List Findings under a given ScanRun.", "parameters": { "pageToken": { "location": "query", "type": "string", "description": "A token identifying a page of results to be returned. This should be a `next_page_token` value returned from a previous List request. If unspecified, the first page of results is returned." }, "parent": { "description": "Required. The parent resource name, which should be a scan run resource name in the format 'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'.", "pattern": "^projects/[^/]+/scanConfigs/[^/]+/scanRuns/[^/]+$", "required": true, "location": "path", "type": "string" }, "filter": { "description": "Required. The filter expression. The expression must be in the format: . Supported field: 'finding_type'. Supported operator: '='.", "location": "query", "type": "string" }, "pageSize": { "description": "The maximum number of Findings to return, can be limited by server. If not specified or not positive, the implementation will select a reasonable value.", "type": "integer", "format": "int32", "location": "query" } }, "path": "v1alpha/{+parent}/findings", "flatPath": "v1alpha/projects/{projectsId}/scanConfigs/{scanConfigsId}/scanRuns/{scanRunsId}/findings", "id": "websecurityscanner.projects.scanConfigs.scanRuns.findings.list", "parameterOrder": [ "parent" ], "response": { "$ref": "ListFindingsResponse" }, "httpMethod": "GET" }, "get": { "id": "websecurityscanner.projects.scanConfigs.scanRuns.findings.get", "description": "Gets a Finding.", "scopes": [ "https://www.googleapis.com/auth/cloud-platform" ], "parameterOrder": [ "name" ], "path": "v1alpha/{+name}", "response": { "$ref": "Finding" }, "parameters": { "name": { "required": true, "location": "path", "description": "Required. The resource name of the Finding to be returned. The name follows the format of 'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}/findings/{findingId}'.", "type": "string", "pattern": "^projects/[^/]+/scanConfigs/[^/]+/scanRuns/[^/]+/findings/[^/]+$" } }, "httpMethod": "GET", "flatPath": "v1alpha/projects/{projectsId}/scanConfigs/{scanConfigsId}/scanRuns/{scanRunsId}/findings/{findingsId}" } } }, "crawledUrls": { "methods": { "list": { "response": { "$ref": "ListCrawledUrlsResponse" }, "path": "v1alpha/{+parent}/crawledUrls", "id": "websecurityscanner.projects.scanConfigs.scanRuns.crawledUrls.list", "parameterOrder": [ "parent" ], "httpMethod": "GET", "description": "List CrawledUrls under a given ScanRun.", "flatPath": "v1alpha/projects/{projectsId}/scanConfigs/{scanConfigsId}/scanRuns/{scanRunsId}/crawledUrls", "parameters": { "parent": { "required": true, "type": "string", "pattern": "^projects/[^/]+/scanConfigs/[^/]+/scanRuns/[^/]+$", "description": "Required. The parent resource name, which should be a scan run resource name in the format 'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'.", "location": "path" }, "pageSize": { "type": "integer", "description": "The maximum number of CrawledUrls to return, can be limited by server. If not specified or not positive, the implementation will select a reasonable value.", "format": "int32", "location": "query" }, "pageToken": { "location": "query", "description": "A token identifying a page of results to be returned. This should be a `next_page_token` value returned from a previous List request. If unspecified, the first page of results is returned.", "type": "string" } }, "scopes": [ "https://www.googleapis.com/auth/cloud-platform" ] } } }, "findingTypeStats": { "methods": { "list": { "parameterOrder": [ "parent" ], "response": { "$ref": "ListFindingTypeStatsResponse" }, "id": "websecurityscanner.projects.scanConfigs.scanRuns.findingTypeStats.list", "httpMethod": "GET", "flatPath": "v1alpha/projects/{projectsId}/scanConfigs/{scanConfigsId}/scanRuns/{scanRunsId}/findingTypeStats", "scopes": [ "https://www.googleapis.com/auth/cloud-platform" ], "parameters": { "parent": { "location": "path", "pattern": "^projects/[^/]+/scanConfigs/[^/]+/scanRuns/[^/]+$", "type": "string", "required": true, "description": "Required. The parent resource name, which should be a scan run resource name in the format 'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'." } }, "path": "v1alpha/{+parent}/findingTypeStats", "description": "List all FindingTypeStats under a given ScanRun." } } } }, "methods": { "stop": { "path": "v1alpha/{+name}:stop", "scopes": [ "https://www.googleapis.com/auth/cloud-platform" ], "parameters": { "name": { "description": "Required. The resource name of the ScanRun to be stopped. The name follows the format of 'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'.", "type": "string", "pattern": "^projects/[^/]+/scanConfigs/[^/]+/scanRuns/[^/]+$", "required": true, "location": "path" } }, "response": { "$ref": "ScanRun" }, "request": { "$ref": "StopScanRunRequest" }, "flatPath": "v1alpha/projects/{projectsId}/scanConfigs/{scanConfigsId}/scanRuns/{scanRunsId}:stop", "id": "websecurityscanner.projects.scanConfigs.scanRuns.stop", "parameterOrder": [ "name" ], "description": "Stops a ScanRun. The stopped ScanRun is returned.", "httpMethod": "POST" }, "get": { "response": { "$ref": "ScanRun" }, "flatPath": "v1alpha/projects/{projectsId}/scanConfigs/{scanConfigsId}/scanRuns/{scanRunsId}", "id": "websecurityscanner.projects.scanConfigs.scanRuns.get", "parameterOrder": [ "name" ], "parameters": { "name": { "type": "string", "description": "Required. The resource name of the ScanRun to be returned. The name follows the format of 'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'.", "required": true, "pattern": "^projects/[^/]+/scanConfigs/[^/]+/scanRuns/[^/]+$", "location": "path" } }, "scopes": [ "https://www.googleapis.com/auth/cloud-platform" ], "httpMethod": "GET", "description": "Gets a ScanRun.", "path": "v1alpha/{+name}" }, "list": { "response": { "$ref": "ListScanRunsResponse" }, "flatPath": "v1alpha/projects/{projectsId}/scanConfigs/{scanConfigsId}/scanRuns", "path": "v1alpha/{+parent}/scanRuns", "httpMethod": "GET", "scopes": [ "https://www.googleapis.com/auth/cloud-platform" ], "parameterOrder": [ "parent" ], "id": "websecurityscanner.projects.scanConfigs.scanRuns.list", "description": "Lists ScanRuns under a given ScanConfig, in descending order of ScanRun stop time.", "parameters": { "parent": { "location": "path", "pattern": "^projects/[^/]+/scanConfigs/[^/]+$", "description": "Required. The parent resource name, which should be a scan resource name in the format 'projects/{projectId}/scanConfigs/{scanConfigId}'.", "type": "string", "required": true }, "pageSize": { "format": "int32", "location": "query", "description": "The maximum number of ScanRuns to return, can be limited by server. If not specified or not positive, the implementation will select a reasonable value.", "type": "integer" }, "pageToken": { "location": "query", "type": "string", "description": "A token identifying a page of results to be returned. This should be a `next_page_token` value returned from a previous List request. If unspecified, the first page of results is returned." } } } } } } } } } }, "fullyEncodeReservedExpansion": true, "documentationLink": "https://cloud.google.com/security-command-center/docs/concepts-web-security-scanner-overview/", "mtlsRootUrl": "https://websecurityscanner.mtls.googleapis.com/", "rootUrl": "https://websecurityscanner.googleapis.com/", "title": "Web Security Scanner API", "version_module": true, "batchPath": "batch", "icons": { "x16": "http://www.google.com/images/icons/product/search-16.gif", "x32": "http://www.google.com/images/icons/product/search-32.gif" }, "canonicalName": "WebSecurityScanner" }
]===]))
