local decode = require("cjson").new().decode
return assert(decode([===[
{ "version": "v1", "canonicalName": "Workflows", "id": "workflows:v1", "basePath": "", "description": "Manage workflow definitions. To execute workflows and manage executions, see the Workflows Executions API.", "revision": "20220623", "baseUrl": "https://workflows.googleapis.com/", "kind": "discovery#restDescription", "ownerName": "Google", "mtlsRootUrl": "https://workflows.mtls.googleapis.com/", "rootUrl": "https://workflows.googleapis.com/", "resources": { "projects": { "resources": { "locations": { "methods": { "list": { "response": { "$ref": "ListLocationsResponse" }, "scopes": [ "https://www.googleapis.com/auth/cloud-platform" ], "path": "v1/{+name}/locations", "id": "workflows.projects.locations.list", "parameterOrder": [ "name" ], "parameters": { "name": { "required": true, "type": "string", "pattern": "^projects/[^/]+$", "location": "path", "description": "The resource that owns the locations collection, if applicable." }, "filter": { "type": "string", "location": "query", "description": "A filter to narrow down results to a preferred subset. The filtering language accepts strings like `\"displayName=tokyo\"`, and is documented in more detail in [AIP-160](https://google.aip.dev/160)." }, "pageToken": { "location": "query", "type": "string", "description": "A page token received from the `next_page_token` field in the response. Send that page token to receive the subsequent page." }, "pageSize": { "type": "integer", "format": "int32", "description": "The maximum number of results to return. If not set, the service selects a default.", "location": "query" } }, "flatPath": "v1/projects/{projectsId}/locations", "description": "Lists information about the supported locations for this service.", "httpMethod": "GET" }, "get": { "id": "workflows.projects.locations.get", "parameters": { "name": { "required": true, "type": "string", "location": "path", "description": "Resource name for the location.", "pattern": "^projects/[^/]+/locations/[^/]+$" } }, "scopes": [ "https://www.googleapis.com/auth/cloud-platform" ], "flatPath": "v1/projects/{projectsId}/locations/{locationsId}", "httpMethod": "GET", "parameterOrder": [ "name" ], "path": "v1/{+name}", "description": "Gets information about a location.", "response": { "$ref": "Location" } } }, "resources": { "workflows": { "methods": { "patch": { "id": "workflows.projects.locations.workflows.patch", "response": { "$ref": "Operation" }, "parameterOrder": [ "name" ], "parameters": { "name": { "location": "path", "description": "The resource name of the workflow. Format: projects/{project}/locations/{location}/workflows/{workflow}", "type": "string", "required": true, "pattern": "^projects/[^/]+/locations/[^/]+/workflows/[^/]+$" }, "updateMask": { "type": "string", "location": "query", "description": "List of fields to be updated. If not present, the entire workflow will be updated.", "format": "google-fieldmask" } }, "path": "v1/{+name}", "request": { "$ref": "Workflow" }, "scopes": [ "https://www.googleapis.com/auth/cloud-platform" ], "flatPath": "v1/projects/{projectsId}/locations/{locationsId}/workflows/{workflowsId}", "httpMethod": "PATCH", "description": "Updates an existing workflow. Running this method has no impact on already running executions of the workflow. A new revision of the workflow may be created as a result of a successful update operation. In that case, such revision will be used in new workflow executions." }, "list": { "parameters": { "filter": { "type": "string", "location": "query", "description": "Filter to restrict results to specific workflows." }, "parent": { "required": true, "location": "path", "type": "string", "description": "Required. Project and location from which the workflows should be listed. Format: projects/{project}/locations/{location}", "pattern": "^projects/[^/]+/locations/[^/]+$" }, "orderBy": { "location": "query", "description": "Comma-separated list of fields that that specify the order of the results. Default sorting order for a field is ascending. To specify descending order for a field, append a \" desc\" suffix. If not specified, the results will be returned in an unspecified order.", "type": "string" }, "pageSize": { "format": "int32", "location": "query", "description": "Maximum number of workflows to return per call. The service may return fewer than this value. If the value is not specified, a default value of 500 will be used. The maximum permitted value is 1000 and values greater than 1000 will be coerced down to 1000.", "type": "integer" }, "pageToken": { "type": "string", "description": "A page token, received from a previous `ListWorkflows` call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to `ListWorkflows` must match the call that provided the page token.", "location": "query" } }, "response": { "$ref": "ListWorkflowsResponse" }, "httpMethod": "GET", "id": "workflows.projects.locations.workflows.list", "flatPath": "v1/projects/{projectsId}/locations/{locationsId}/workflows", "description": "Lists Workflows in a given project and location. The default order is not specified.", "path": "v1/{+parent}/workflows", "scopes": [ "https://www.googleapis.com/auth/cloud-platform" ], "parameterOrder": [ "parent" ] }, "get": { "parameters": { "name": { "type": "string", "description": "Required. Name of the workflow which information should be retrieved. Format: projects/{project}/locations/{location}/workflows/{workflow}", "required": true, "pattern": "^projects/[^/]+/locations/[^/]+/workflows/[^/]+$", "location": "path" } }, "path": "v1/{+name}", "flatPath": "v1/projects/{projectsId}/locations/{locationsId}/workflows/{workflowsId}", "httpMethod": "GET", "id": "workflows.projects.locations.workflows.get", "parameterOrder": [ "name" ], "scopes": [ "https://www.googleapis.com/auth/cloud-platform" ], "response": { "$ref": "Workflow" }, "description": "Gets details of a single Workflow." }, "delete": { "response": { "$ref": "Operation" }, "description": "Deletes a workflow with the specified name. This method also cancels and deletes all running executions of the workflow.", "flatPath": "v1/projects/{projectsId}/locations/{locationsId}/workflows/{workflowsId}", "id": "workflows.projects.locations.workflows.delete", "parameterOrder": [ "name" ], "parameters": { "name": { "location": "path", "description": "Required. Name of the workflow to be deleted. Format: projects/{project}/locations/{location}/workflows/{workflow}", "pattern": "^projects/[^/]+/locations/[^/]+/workflows/[^/]+$", "required": true, "type": "string" } }, "path": "v1/{+name}", "scopes": [ "https://www.googleapis.com/auth/cloud-platform" ], "httpMethod": "DELETE" }, "create": { "request": { "$ref": "Workflow" }, "path": "v1/{+parent}/workflows", "httpMethod": "POST", "response": { "$ref": "Operation" }, "description": "Creates a new workflow. If a workflow with the specified name already exists in the specified project and location, the long running operation will return ALREADY_EXISTS error.", "flatPath": "v1/projects/{projectsId}/locations/{locationsId}/workflows", "parameterOrder": [ "parent" ], "parameters": { "parent": { "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+$", "description": "Required. Project and location in which the workflow should be created. Format: projects/{project}/locations/{location}", "required": true, "location": "path" }, "workflowId": { "location": "query", "description": "Required. The ID of the workflow to be created. It has to fulfill the following requirements: LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh Must contain only letters, numbers, underscores and hyphens. LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh Must start with a letter. LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh Must be between 1-64 characters. LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh Must end with a number or a letter. LICENSE Makefile README.md gsa_key.json lua-resty-gcp-dev-1.rockspec lua-resty-gcp-scm-1.rockspec.original lua-resty-gcp-scm-1.rockspec.template spec src upload.sh Must be unique within the customer project and location.", "type": "string" } }, "id": "workflows.projects.locations.workflows.create", "scopes": [ "https://www.googleapis.com/auth/cloud-platform" ] } } }, "operations": { "methods": { "get": { "response": { "$ref": "Operation" }, "id": "workflows.projects.locations.operations.get", "path": "v1/{+name}", "parameters": { "name": { "type": "string", "location": "path", "pattern": "^projects/[^/]+/locations/[^/]+/operations/[^/]+$", "description": "The name of the operation resource.", "required": true } }, "flatPath": "v1/projects/{projectsId}/locations/{locationsId}/operations/{operationsId}", "description": "Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.", "scopes": [ "https://www.googleapis.com/auth/cloud-platform" ], "parameterOrder": [ "name" ], "httpMethod": "GET" }, "list": { "scopes": [ "https://www.googleapis.com/auth/cloud-platform" ], "path": "v1/{+name}/operations", "description": "Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`. NOTE: the `name` binding allows API services to override the binding to use different resource name schemes, such as `users/*/operations`. To override the binding, API services can add a binding such as `\"/v1/{name=users/*}/operations\"` to their service configuration. For backwards compatibility, the default name includes the operations collection id, however overriding users must ensure the name binding is the parent resource, without the operations collection id.", "response": { "$ref": "ListOperationsResponse" }, "parameters": { "filter": { "location": "query", "description": "The standard list filter.", "type": "string" }, "name": { "required": true, "pattern": "^projects/[^/]+/locations/[^/]+$", "location": "path", "type": "string", "description": "The name of the operation's parent resource." }, "pageToken": { "type": "string", "location": "query", "description": "The standard list page token." }, "pageSize": { "location": "query", "type": "integer", "format": "int32", "description": "The standard list page size." } }, "httpMethod": "GET", "parameterOrder": [ "name" ], "id": "workflows.projects.locations.operations.list", "flatPath": "v1/projects/{projectsId}/locations/{locationsId}/operations" }, "delete": { "flatPath": "v1/projects/{projectsId}/locations/{locationsId}/operations/{operationsId}", "id": "workflows.projects.locations.operations.delete", "httpMethod": "DELETE", "response": { "$ref": "Empty" }, "scopes": [ "https://www.googleapis.com/auth/cloud-platform" ], "parameterOrder": [ "name" ], "description": "Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`.", "parameters": { "name": { "location": "path", "required": true, "pattern": "^projects/[^/]+/locations/[^/]+/operations/[^/]+$", "description": "The name of the operation resource to be deleted.", "type": "string" } }, "path": "v1/{+name}" } } } } } } } }, "auth": { "oauth2": { "scopes": { "https://www.googleapis.com/auth/cloud-platform": { "description": "See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account." } } } }, "fullyEncodeReservedExpansion": true, "protocol": "rest", "name": "workflows", "schemas": { "OperationMetadata": { "description": "Represents the metadata of the long-running operation.", "properties": { "verb": { "description": "Name of the verb executed by the operation.", "type": "string" }, "apiVersion": { "type": "string", "description": "API version used to start the operation." }, "createTime": { "type": "string", "format": "google-datetime", "description": "The time the operation was created." }, "endTime": { "format": "google-datetime", "description": "The time the operation finished running.", "type": "string" }, "target": { "description": "Server-defined resource path for the target of the operation.", "type": "string" } }, "type": "object", "id": "OperationMetadata" }, "Empty": { "id": "Empty", "description": "A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance: service Foo { rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty); }", "type": "object", "properties": {} }, "Status": { "description": "The `Status` type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by [gRPC](https://github.com/grpc). Each `Status` message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the [API Design Guide](https://cloud.google.com/apis/design/errors).", "properties": { "details": { "description": "A list of messages that carry the error details. There is a common set of message types for APIs to use.", "items": { "type": "object", "additionalProperties": { "type": "any", "description": "Properties of the object. Contains field @type with type URL." } }, "type": "array" }, "message": { "type": "string", "description": "A developer-facing error message, which should be in English. Any user-facing error message should be localized and sent in the google.rpc.Status.details field, or localized by the client." }, "code": { "format": "int32", "description": "The status code, which should be an enum value of google.rpc.Code.", "type": "integer" } }, "type": "object", "id": "Status" }, "ListWorkflowsResponse": { "id": "ListWorkflowsResponse", "description": "Response for the ListWorkflows method.", "properties": { "unreachable": { "items": { "type": "string" }, "description": "Unreachable resources.", "type": "array" }, "nextPageToken": { "type": "string", "description": "A token, which can be sent as `page_token` to retrieve the next page. If this field is omitted, there are no subsequent pages." }, "workflows": { "items": { "$ref": "Workflow" }, "description": "The workflows which match the request.", "type": "array" } }, "type": "object" }, "ListOperationsResponse": { "description": "The response message for Operations.ListOperations.", "properties": { "nextPageToken": { "type": "string", "description": "The standard List next-page token." }, "operations": { "type": "array", "description": "A list of operations that matches the specified filter in the request.", "items": { "$ref": "Operation" } } }, "type": "object", "id": "ListOperationsResponse" }, "Location": { "type": "object", "id": "Location", "description": "A resource that represents Google Cloud Platform location.", "properties": { "locationId": { "type": "string", "description": "The canonical id for this location. For example: `\"us-east1\"`." }, "metadata": { "type": "object", "description": "Service-specific metadata. For example the available capacity at the given location.", "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" } }, "labels": { "additionalProperties": { "type": "string" }, "type": "object", "description": "Cross-service attributes for the location. For example {\"cloud.googleapis.com/region\": \"us-east1\"}" }, "name": { "description": "Resource name for the location, which may vary between implementations. For example: `\"projects/example-project/locations/us-east1\"`", "type": "string" }, "displayName": { "type": "string", "description": "The friendly name for this location, typically a nearby city name. For example, \"Tokyo\"." } } }, "Operation": { "type": "object", "id": "Operation", "properties": { "metadata": { "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "type": "object", "description": "Service-specific metadata associated with the operation. It typically contains progress information and common metadata such as create time. Some services might not provide such metadata. Any method that returns a long-running operation should document the metadata type, if any." }, "name": { "description": "The server-assigned name, which is only unique within the same service that originally returns it. If you use the default HTTP mapping, the `name` should be a resource name ending with `operations/{unique_id}`.", "type": "string" }, "done": { "type": "boolean", "description": "If the value is `false`, it means the operation is still in progress. If `true`, the operation is completed, and either `error` or `response` is available." }, "response": { "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "description": "The normal response of the operation in case of success. If the original method returns no data on success, such as `Delete`, the response is `google.protobuf.Empty`. If the original method is standard `Get`/`Create`/`Update`, the response should be the resource. For other methods, the response should have the type `XxxResponse`, where `Xxx` is the original method name. For example, if the original method name is `TakeSnapshot()`, the inferred response type is `TakeSnapshotResponse`.", "type": "object" }, "error": { "description": "The error result of the operation in case of failure or cancellation.", "$ref": "Status" } }, "description": "This resource represents a long-running operation that is the result of a network API call." }, "ListLocationsResponse": { "properties": { "locations": { "description": "A list of locations that matches the specified filter in the request.", "items": { "$ref": "Location" }, "type": "array" }, "nextPageToken": { "description": "The standard List next-page token.", "type": "string" } }, "description": "The response message for Locations.ListLocations.", "id": "ListLocationsResponse", "type": "object" }, "Workflow": { "id": "Workflow", "type": "object", "properties": { "description": { "description": "Description of the workflow provided by the user. Must be at most 1000 unicode characters long.", "type": "string" }, "revisionCreateTime": { "format": "google-datetime", "type": "string", "readOnly": true, "description": "Output only. The timestamp that the latest revision of the workflow was created." }, "serviceAccount": { "type": "string", "description": "The service account associated with the latest workflow version. This service account represents the identity of the workflow and determines what permissions the workflow has. Format: projects/{project}/serviceAccounts/{account} or {account} Using `-` as a wildcard for the `{project}` or not providing one at all will infer the project from the account. The `{account}` value can be the `email` address or the `unique_id` of the service account. If not provided, workflow will use the project's default service account. Modifying this field for an existing workflow results in a new workflow revision." }, "state": { "enumDescriptions": [ "Invalid state.", "The workflow has been deployed successfully and is serving." ], "type": "string", "enum": [ "STATE_UNSPECIFIED", "ACTIVE" ], "description": "Output only. State of the workflow deployment.", "readOnly": true }, "sourceContents": { "type": "string", "description": "Workflow code to be executed. The size limit is 128KB." }, "labels": { "type": "object", "additionalProperties": { "type": "string" }, "description": "Labels associated with this workflow. Labels can contain at most 64 entries. Keys and values can be no longer than 63 characters and can only contain lowercase letters, numeric characters, underscores and dashes. Label keys must start with a letter. International characters are allowed." }, "updateTime": { "type": "string", "readOnly": true, "description": "Output only. The last update timestamp of the workflow.", "format": "google-datetime" }, "revisionId": { "readOnly": true, "description": "Output only. The revision of the workflow. A new revision of a workflow is created as a result of updating the following properties of a workflow: - Service account - Workflow code to be executed The format is \"000001-a4d\", where the first 6 characters define the zero-padded revision ordinal number. They are followed by a hyphen and 3 hexadecimal random characters.", "type": "string" }, "createTime": { "type": "string", "format": "google-datetime", "readOnly": true, "description": "Output only. The timestamp of when the workflow was created." }, "name": { "description": "The resource name of the workflow. Format: projects/{project}/locations/{location}/workflows/{workflow}", "type": "string" } }, "description": "Workflow program to be executed by Workflows." } }, "documentationLink": "https://cloud.google.com/workflows", "parameters": { "upload_protocol": { "description": "Upload protocol for media (e.g. \"raw\", \"multipart\").", "location": "query", "type": "string" }, "prettyPrint": { "description": "Returns response with indentations and line breaks.", "type": "boolean", "location": "query", "default": "true" }, "quotaUser": { "type": "string", "location": "query", "description": "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters." }, "callback": { "location": "query", "description": "JSONP", "type": "string" }, "uploadType": { "description": "Legacy upload protocol for media (e.g. \"media\", \"multipart\").", "type": "string", "location": "query" }, "oauth_token": { "type": "string", "location": "query", "description": "OAuth 2.0 token for the current user." }, "access_token": { "location": "query", "description": "OAuth access token.", "type": "string" }, "$.xgafv": { "enum": [ "1", "2" ], "description": "V1 error format.", "type": "string", "enumDescriptions": [ "v1 error format", "v2 error format" ], "location": "query" }, "fields": { "description": "Selector specifying which fields to include in a partial response.", "type": "string", "location": "query" }, "key": { "location": "query", "type": "string", "description": "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token." }, "alt": { "default": "json", "type": "string", "enumDescriptions": [ "Responses with Content-Type of application/json", "Media download with context-dependent Content-Type", "Responses with Content-Type of application/x-protobuf" ], "enum": [ "json", "media", "proto" ], "location": "query", "description": "Data format for response." } }, "batchPath": "batch", "discoveryVersion": "v1", "version_module": true, "title": "Workflows API", "servicePath": "", "icons": { "x16": "http://www.google.com/images/icons/product/search-16.gif", "x32": "http://www.google.com/images/icons/product/search-32.gif" }, "ownerDomain": "google.com" }
]===]))
